ONNX Runtime: cross-platform, high performance ML inferencing and training accelerator
This report presents the forensic synthetic code analysis of microsoft/onnxruntime, a C++ project with 21,083 GitHub stars. SynthScan v2.0 examined 1,260,596 lines of code across 5488 source files, recording 7016 pattern matches distributed across 23 syntactic categories. The overall adjusted score of 8.4 places this repository in the Low AI signal band.
The scanner applied 160+ deterministic lexical heuristics, multi-line block detectors, abstract syntax tree depth profilers, and a cross-file Jaccard similarity matrix to construct a statistically normalised synthetic code estimate. All matches are individually weighted by severity coefficient and contextual multiplier before summation, and the resulting headline score is temporally discounted to account for the repository's development history relative to the commercial emergence of large language model coding tooling (November 2022 onward).
This chart maps the temporal evolution of the adjusted synthetic code score across successive scan runs. An upward trajectory indicates ongoing incorporation of AI-generated code or expanding LLM-assisted scaffolding; a stable or declining trajectory may reflect active human refactoring, code removal, or the adoption of stricter authorship policies. The dashed secondary line (right axis) independently tracks total raw pattern hit count, which can diverge from the normalised score when codebase size changes significantly between scans.
Classifies detected patterns by their diagnostic confidence and structural impact. CRITICAL patterns (coefficient 10) represent definitive synthetic signatures — hallucinated imports, explicit LLM attribution metadata — virtually never produced by human authors. HIGH (5) indicates strong structural tells such as cross-file repetition or cross-linguistic idioms. MEDIUM (2) covers recognisable conversational padding and AI-specific vocabulary. LOW (1) captures subtle indicators like tautological comments and generic boilerplate that require density to carry independent signal.
This horizontal bar chart decomposes the repository's raw synthetic code score by top-level directory, allowing you to pinpoint precisely which modules or components carry the highest AI authorship density. Directories with disproportionately high scores relative to their size warrant targeted manual review: concentrated AI signatures often trace back to mass-generated configuration layers, auto-ported test suites, LLM-scaffolded boilerplate classes, or entire subsystems authored under heavy copilot assistance. Use this view to prioritise your human code-review effort.
The scanner identified 7016 distinct pattern matches across 23 syntactic categories. Each entry below represents a discrete location in the source code where the engine recorded a statistically significant AI authorship indicator. Expand any category row to inspect the individual file paths, line numbers, code snippets, and the lexical context (CODE, COMMENT, or STRING) in which each match was detected.
Reading the findings table: The Severity column indicates the diagnostic confidence level (CRITICAL / HIGH / MEDIUM / LOW). The Context column identifies whether the match occurred inside executable code, an inline comment, or a string literal — comment-context matches receive a ×1.5 weight because LLMs systematically over-annotate. The ⚡ bolt icon marks clustered matches: three or more patterns within a 10-line window, each receiving an additional ×1.5 density multiplier as dense clusters constitute far stronger evidence of synthetic authorship than isolated hits.
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| MEDIUM | setup.py | 1 | # ------------------------------------------------------------------------ | COMMENT |
| MEDIUM | setup.py | 4 | # ------------------------------------------------------------------------ | COMMENT |
| MEDIUM | tools/ci_build/compile_triton.py | 1 | # ------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/compile_triton.py | 4 | # -------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/set-trigger-rules.py | 1 | # ------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/set-trigger-rules.py | 4 | # -------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/cuda_plugin_parity_report.py | 517 | # ============================================================================ | COMMENT |
| MEDIUM | tools/ci_build/cuda_plugin_parity_report.py | 519 | # ============================================================================ | COMMENT |
| MEDIUM⚡ | tools/ci_build/github/Doxyfile_csharp.cfg | 2179 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | tools/ci_build/github/Doxyfile_csharp.cfg | 2181 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | tools/ci_build/github/Doxyfile_csharp.cfg | 2191 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | tools/ci_build/github/Doxyfile_csharp.cfg | 2193 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 25 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 27 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 491 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 493 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 810 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 812 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 901 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 903 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 1067 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 1069 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 1193 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 1195 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 1212 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 1214 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 1843 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 1845 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 2027 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 2029 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 2083 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 2085 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 2127 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 2129 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 2161 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 2163 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 2229 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 2231 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 2308 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 2310 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 2354 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 2356 | #--------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/python/sparsify_initializers.py | 1 | # ------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/python/sparsify_initializers.py | 4 | # -------------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/python/wgsl_template/code_pattern.py | 16 | # ---------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/python/wgsl_template/code_pattern.py | 18 | # ---------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/python/wgsl_template/code_pattern.py | 49 | # ---------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/python/wgsl_template/code_pattern.py | 51 | # ---------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/python/wgsl_template/code_pattern.py | 67 | # ---------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/python/wgsl_template/code_pattern.py | 69 | # ---------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/python/wgsl_template/code_pattern.py | 94 | # ---------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/python/wgsl_template/code_pattern.py | 96 | # ---------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/python/wgsl_template/code_pattern.py | 208 | # ---------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/python/wgsl_template/code_pattern.py | 210 | # ---------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/python/wgsl_template/types.py | 73 | # ---------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/python/wgsl_template/types.py | 75 | # ---------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/python/wgsl_template/parser.py | 36 | # ---------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/python/wgsl_template/parser.py | 38 | # ---------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/python/wgsl_template/parser.py | 103 | # ---------------------------------------------------------------------- | COMMENT |
| MEDIUM | tools/python/wgsl_template/parser.py | 105 | # ---------------------------------------------------------------------- | COMMENT |
| 1061 more matches not shown… | ||||
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| LOW | ThirdPartyNotices.txt | 1721 | # | COMMENT |
| LOW | setup.py | 741 | build_suffix = environ.get("BUILD_BUILDNUMBER") | COMMENT |
| LOW | .lintrunner.toml | 1 | # Configuration for lintrunner https://github.com/suo/lintrunner | COMMENT |
| LOW | tools/ci_build/build.py | 1281 | if var in os.environ: | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 1 | # Doxyfile 1.9.4 | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 21 | # Use doxygen to compare the used configuration file with the template | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 41 | # double-quotes, unless you are using Doxywizard) that should identify the | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 61 | # in the documentation. The maximum height of the logo should not exceed 55 | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 81 | # The default value is: NO. | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 101 | COMMENT | |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 121 | # documentation (similar to Javadoc). Set to NO to disable this. | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 161 | ALWAYS_DETAILED_SEC = NO | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 181 | # If left blank the directory from which doxygen is run is used as the path to | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 201 | # support long names like on DOS, Mac, or CD-ROM. | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 221 | # The default value is: NO. | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 241 | # The default value is: NO. | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 261 | # of the file/class/namespace that contains it. | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 281 | # of an alias to insert a newline as if a physical newline was in the original | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 301 | # The default value is: NO. | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 321 | # The default value is: NO. | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 341 | # the files are not read by doxygen. When specifying no_extension you should add | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 361 | # Note: This feature currently applies only to Markdown headings. | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 381 | # The default value is: NO. | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 401 | # doxygen to replace the get and set methods by a property in the documentation. | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 421 | COMMENT | |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 441 | COMMENT | |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 461 | # The default value is: NO. | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 481 | # than 0 to get more control over the balance between CPU load and processing | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 521 | EXTRACT_PACKAGE = NO | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 541 | # The default value is: NO. | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 561 | # If the HIDE_UNDOC_MEMBERS tag is set to YES, doxygen will hide all | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 581 | COMMENT | |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 601 | # whose names only differ in casing), the option must be set to YES to properly | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 621 | # If the HIDE_COMPOUND_REFERENCE tag is set to NO (default) then doxygen will | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 641 | # grouped member an include statement to the documentation, telling the reader | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 661 | # name. If set to NO, the members will appear in declaration order. | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 681 | # detailed member documentation. | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 701 | SORT_BY_SCOPE_NAME = NO | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 721 | # The default value is: YES. | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 741 | COMMENT | |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 761 | COMMENT | |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 781 | # by doxygen. Whatever the program writes to standard output is used as the file | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 801 | # the reference definitions. This must be a list of .bib files. The .bib | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 821 | # The WARNINGS tag can be used to turn on/off the warning messages that are | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 841 | # The default value is: YES. | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 861 | COMMENT | |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 881 | COMMENT | |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 901 | #--------------------------------------------------------------------------- | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 921 | INPUT_ENCODING = UTF-8 | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 941 | FILE_PATTERNS = *.cs | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 961 | # The default value is: NO. | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 981 | # exclude all test directories use the pattern */test/* | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 1001 | # The default value is: NO. | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 1021 | # | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 1041 | # properly processed by doxygen. | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 1061 | # is part of the input, its contents will be placed on the main page | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 1081 | # classes and enums directly into the documentation. | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 1101 | # The default value is: NO. | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 1121 | SOURCE_TOOLTIPS = YES | COMMENT |
| LOW | tools/ci_build/github/Doxyfile_csharp.cfg | 1141 | # This tag requires that the tag SOURCE_BROWSER is set to YES. | COMMENT |
| 2042 more matches not shown… | ||||
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| LOW | setup.py | 188 | def _rewrite_ld_preload_tensorrt(self, to_preload): | CODE |
| LOW | setup.py | 201 | def _rewrite_ld_preload_nv_tensorrt_rtx(self, to_preload): | CODE |
| LOW | setup.py | 834 | def save_build_and_package_info(package_name, version_number, cuda_version, qnn_version): | CODE |
| LOW | tools/ci_build/build.py | 208 | def number_of_test_parallel_jobs(args): | CODE |
| LOW | tools/ci_build/build.py | 221 | def number_of_flash_nvcc_threads(args): | CODE |
| LOW | tools/ci_build/build.py | 229 | def generate_vcpkg_install_options(build_dir, args): | CODE |
| LOW | tools/ci_build/build.py | 1903 | def parse_cuda_version_from_json(cuda_home): | CODE |
| LOW | tools/ci_build/op_registration_utils.py | 19 | def map_ort_constant_to_domain(ort_constant_name: str, allow_unknown_constant: bool = True): | CODE |
| LOW | tools/ci_build/op_registration_utils.py | 53 | def get_kernel_registration_files(ort_root=None, include_cuda=False): | CODE |
| LOW | tools/ci_build/op_registration_utils.py | 240 | def process_kernel_registration_file(filename: str | pathlib.Path, registration_processor: RegistrationProcessor): | CODE |
| LOW | tools/ci_build/manage_java_artifacts.py | 56 | def create_zip_from_directory(zip_file_path: Path, source_dir: Path): | CODE |
| LOW | tools/ci_build/build_args.py | 41 | def _openvino_verify_device_type(device_read: str) -> str: | CODE |
| LOW | tools/ci_build/build_args.py | 99 | def _webgpu_verify_library_kind(library_kind: str) -> str: | CODE |
| LOW | tools/ci_build/build_args.py | 170 | def add_cmake_build_config_args(parser: argparse.ArgumentParser) -> None: | CODE |
| LOW | tools/ci_build/build_args.py | 255 | def add_general_profiling_args(parser: argparse.ArgumentParser) -> None: | CODE |
| LOW | tools/ci_build/build_args.py | 260 | def add_debugging_sanitizer_args(parser: argparse.ArgumentParser) -> None: | CODE |
| LOW | tools/ci_build/build_args.py | 432 | def add_windows_specific_args(parser: argparse.ArgumentParser) -> None: | CODE |
| LOW | tools/ci_build/build_args.py | 584 | def add_threadpool_callback_args(parser: argparse.ArgumentParser) -> None: | CODE |
| LOW | tools/ci_build/build_args.py | 641 | def add_execution_provider_args(parser: argparse.ArgumentParser) -> None: | CODE |
| LOW | tools/ci_build/reduce_op_kernels.py | 31 | def _adapt_filters_for_extended_minimal_build( | CODE |
| LOW | tools/ci_build/reduce_op_kernels.py | 86 | def is_typed_registration_needed(self, domain: str, optype: str, type_registration_str: str): | CODE |
| LOW | tools/ci_build/reduce_op_kernels.py | 191 | def _get_op_reduction_file_path(ort_root: Path, build_dir: Path, original_path: Path): | CODE |
| LOW | tools/ci_build/reduce_op_kernels.py | 200 | def _generate_provider_registrations( | CODE |
| LOW | tools/ci_build/reduce_op_kernels.py | 234 | def _generate_type_control_overrides(ort_root: Path, build_dir: Path, cpp_lines: typing.Sequence[str]): | CODE |
| LOW | …ols/ci_build/upload_python_package_to_azure_storage.py | 15 | def parse_nightly_and_local_version_from_whl_name(blob_name): | CODE |
| LOW | tools/ci_build/cuda_plugin_parity_report.py | 212 | def _extract_wrapper_registrations(content, file_path): | CODE |
| LOW | tools/ci_build/cuda_plugin_parity_report.py | 257 | def extract_kernel_registrations(file_path): | CODE |
| LOW | tools/ci_build/test_compile_triton.py | 13 | def load_compile_triton_module(): | CODE |
| LOW | tools/ci_build/test_compile_triton.py | 27 | def test_convert_lib_to_obj_uses_subprocess_run(self): | CODE |
| LOW | tools/ci_build/test_compile_triton.py | 54 | def test_archive_obj_files_uses_subprocess_run(self): | CODE |
| LOW | tools/ci_build/test_compile_triton.py | 77 | def test_convert_lib_to_obj_surfaces_subprocess_errors(self): | CODE |
| LOW | tools/ci_build/test_compile_triton.py | 93 | def test_archive_obj_files_surfaces_os_errors(self): | CODE |
| LOW | tools/ci_build/op_registration_validator.py | 80 | def _validate_all_registrations(self) -> int: | CODE |
| LOW | tools/ci_build/op_registration_validator.py | 85 | def registration_info_sort_key(r: RegistrationInfo): | CODE |
| LOW | tools/ci_build/op_registration_validator.py | 105 | def _validate_registrations_for_domain_and_op(self, registrations: typing.Iterator[RegistrationInfo]) -> int: | CODE |
| LOW | tools/ci_build/op_registration_validator.py | 159 | def _validate_last_registration(self, last_r: RegistrationInfo) -> bool: | CODE |
| LOW | tools/ci_build/op_registration_validator.py | 208 | def validate_registration_file(file: str) -> bool: | CODE |
| LOW | tools/ci_build/github/apple/package_release_tasks.py | 44 | def _resolve_single_path_from_pattern(path_pattern: str) -> Path: | CODE |
| LOW | tools/ci_build/github/apple/build_apple_framework.py | 23 | def _filter_sysroot_arch_pairs( | CODE |
| LOW | tools/ci_build/github/apple/build_apple_framework.py | 53 | def _find_or_build_sysroot_arch_framework( | CODE |
| LOW | tools/ci_build/github/apple/build_apple_framework.py | 105 | def _write_sysroot_arch_framework_build_outputs_to_file( | CODE |
| LOW | tools/ci_build/github/apple/build_apple_framework.py | 131 | def _assemble_fat_framework_for_sysroot( | CODE |
| LOW | tools/ci_build/github/apple/build_apple_framework.py | 200 | def _merge_framework_info_files(files: list[pathlib.Path], output_file: pathlib.Path): | CODE |
| LOW | …ols/ci_build/github/apple/get_simulator_device_info.py | 38 | def get_simulator_device_info( | CODE |
| LOW | …ols/ci_build/github/apple/get_simulator_device_info.py | 119 | def runtime_id_and_device_pair_key(runtime_id_and_device_pair): | CODE |
| LOW | tools/ci_build/github/apple/build_settings_utils.py | 13 | def parse_build_settings_file(build_settings_file: pathlib.Path) -> dict[str, typing.Any]: | CODE |
| LOW | tools/ci_build/github/apple/build_settings_utils.py | 28 | def validate_str_to_str_list_dict(input: dict[str, list[str]]): | CODE |
| LOW | tools/ci_build/github/apple/package_assembly_utils.py | 38 | def replace_template_variable(match): | CODE |
| LOW | tools/ci_build/github/apple/package_assembly_utils.py | 78 | def copy_repo_relative_to_dir(patterns: list[str], dest_dir: pathlib.Path): | CODE |
| LOW | …d/github/apple/objectivec/assemble_objc_pod_package.py | 104 | def assemble_objc_pod_package(staging_dir: pathlib.Path, pod_version: str, framework_info_file: pathlib.Path): | CODE |
| LOW | …d/github/apple/objectivec/assemble_objc_pod_package.py | 136 | def path_patterns_as_variable_value(patterns: list[str]): | CODE |
| LOW | tools/ci_build/github/windows/jar_packaging.py | 80 | def archive_directory_contents(archive_path: Path, source_dir: Path, description: str): | CODE |
| LOW | tools/python/compile_contributors.py | 115 | def extract_authors_from_commit(commit_id): | CODE |
| LOW⚡ | tools/python/cherry_pick_utils.py | 69 | def get_pr_number_from_subject(subject): | CODE |
| LOW | tools/python/create_reduced_build_config.py | 14 | def _get_suffix_match_predicate(suffix: str): | CODE |
| LOW | tools/python/create_reduced_build_config.py | 21 | def _extract_ops_from_onnx_graph(graph, operators, domain_opset_map): | CODE |
| LOW | tools/python/create_reduced_build_config.py | 63 | def _extract_ops_from_onnx_model(model_files: typing.Iterable[pathlib.Path]): | CODE |
| LOW | tools/python/create_reduced_build_config.py | 76 | def create_config_from_onnx_models(model_files: typing.Iterable[pathlib.Path], output_file: pathlib.Path): | CODE |
| LOW | tools/python/upload_and_run_browserstack_tests.py | 32 | def browserstack_build_request(devices, app_url, test_suite_url, test_platform, id, token, project, build_tag): | STRING |
| LOW | tools/python/gen_contrib_doc.py | 84 | def display_function_version_link(name, version): # type: (Text, int) -> Text | CODE |
| 1644 more matches not shown… | ||||
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| MEDIUM | tools/ci_build/build.py | 572 | # This file is for building the vcpkg ports. | COMMENT |
| MEDIUM | tools/ci_build/prepare_macos_package.py | 156 | # Create a zip file in the staging directory. | COMMENT |
| MEDIUM | …azure-pipelines/stages/plugin-cuda-packaging-stage.yml | 340 | # Create a version folder in the output artifact with a file whose name is the version string. | COMMENT |
| MEDIUM | …ure-pipelines/stages/set_packaging_variables_stage.yml | 59 | # Create the file with the first parameter | COMMENT |
| MEDIUM | …ure-pipelines/stages/plugin-webgpu-packaging-stage.yml | 231 | # Create a version folder in the output artifact with a file whose name is the version string. | COMMENT |
| MEDIUM | …d/github/azure-pipelines/templates/c-api-linux-cpu.yml | 1 | # This file contains the ADO job that build libonnxruntime.so on Linux | COMMENT |
| MEDIUM | …hub/azure-pipelines/templates/android-java-api-aar.yml | 91 | # Create a folder for artifacts | COMMENT |
| MEDIUM | …lines/templates/set-plugin-ep-build-variables-step.yml | 1 | # This file is used to set variables for plugin build stages. It sets the package version | COMMENT |
| MEDIUM | …build/github/azure-pipelines/templates/setup-maven.yml | 9 | # Define the scope for the access token | COMMENT |
| MEDIUM | …b/azure-pipelines/templates/make_java_win_binaries.yml | 51 | # Define the path to the python script within your repository | COMMENT |
| MEDIUM | tools/python/update_version.py | 39 | # Create a new row based on the separator, replacing dashes with spaces and adding the version | COMMENT |
| MEDIUM | tools/python/gen_contrib_doc.py | 3 | # This file is copied and adapted from https://github.com/onnx/onnx repository. | COMMENT |
| MEDIUM | tools/python/util/vcpkg_helpers.py | 578 | # Define the path to the intermediate toolchain file used by vcpkg for wasm | STRING |
| MEDIUM | tools/python/util/vcpkg_helpers.py | 625 | cxxflags = list(base_flags) # Create a copy | STRING |
| MEDIUM | tools/python/util/convert_onnx_models_to_ort.py | 133 | # Create an ONNX file with the same optimization level that will be used for the ORT format file. | COMMENT |
| MEDIUM | tools/python/util/test/test_onnx_model_utils.py | 58 | # Create the main graph | COMMENT |
| MEDIUM | tools/nuget/generate_nuspec_for_native_nuget.py | 1241 | # Create the nuspec needed to generate the Nuget | COMMENT |
| MEDIUM | onnxruntime/core/flatbuffers/schema/compile_schema.py | 103 | # Create a copy of the schema so we can replace the namespace so that the generated module name doesn't | COMMENT |
| MEDIUM | …rs/ort_flatbuffers_py/fbs/RuntimeOptimizationRecord.py | 23 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …/ort_flatbuffers_py/fbs/DeprecatedKernelCreateInfos.py | 22 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …ffers/ort_flatbuffers_py/fbs/NodesToOptimizeIndices.py | 23 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …e/core/flatbuffers/ort_flatbuffers_py/fbs/Attribute.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …ore/flatbuffers/ort_flatbuffers_py/fbs/SequenceType.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …ffers/ort_flatbuffers_py/fbs/DeprecatedSessionState.py | 22 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …flatbuffers/ort_flatbuffers_py/fbs/InferenceSession.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …/core/flatbuffers/ort_flatbuffers_py/fbs/Checkpoint.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …e/flatbuffers/ort_flatbuffers_py/fbs/OptimizerGroup.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …re/flatbuffers/ort_flatbuffers_py/fbs/OperatorSetId.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …core/flatbuffers/ort_flatbuffers_py/fbs/PropertyBag.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …e/core/flatbuffers/ort_flatbuffers_py/fbs/ValueInfo.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …buffers/ort_flatbuffers_py/fbs/RuntimeOptimizations.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …s/ort_flatbuffers_py/fbs/OpIdKernelTypeStrArgsEntry.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …ntime/core/flatbuffers/ort_flatbuffers_py/fbs/Graph.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …ime/core/flatbuffers/ort_flatbuffers_py/fbs/MapType.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …atbuffers/ort_flatbuffers_py/fbs/TensorTypeAndShape.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …fers/ort_flatbuffers_py/fbs/ParameterOptimizerState.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …ore/flatbuffers/ort_flatbuffers_py/fbs/SparseTensor.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …fers_py/fbs/RuntimeOptimizationRecordContainerEntry.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …e/flatbuffers/ort_flatbuffers_py/fbs/DimensionValue.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …me/core/flatbuffers/ort_flatbuffers_py/fbs/TypeInfo.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …uffers/ort_flatbuffers_py/fbs/KernelTypeStrResolver.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …ntime/core/flatbuffers/ort_flatbuffers_py/fbs/Model.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …time/core/flatbuffers/ort_flatbuffers_py/fbs/Tensor.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …t_flatbuffers_py/fbs/DeprecatedSubGraphSessionState.py | 22 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …tbuffers_py/fbs/DeprecatedNodeIndexAndKernelDefHash.py | 22 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …latbuffers/ort_flatbuffers_py/fbs/StringStringEntry.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …me/core/flatbuffers/ort_flatbuffers_py/fbs/NodeEdge.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …ntime/core/flatbuffers/ort_flatbuffers_py/fbs/Shape.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …e/flatbuffers/ort_flatbuffers_py/fbs/StringProperty.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …core/flatbuffers/ort_flatbuffers_py/fbs/ModuleState.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …untime/core/flatbuffers/ort_flatbuffers_py/fbs/Node.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …re/flatbuffers/ort_flatbuffers_py/fbs/FloatProperty.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …ffers/ort_flatbuffers_py/fbs/KernelTypeStrArgsEntry.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …/flatbuffers/ort_flatbuffers_py/fbs/ArgTypeAndIndex.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …core/flatbuffers/ort_flatbuffers_py/fbs/IntProperty.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | …e/core/flatbuffers/ort_flatbuffers_py/fbs/Dimension.py | 21 | """This method is deprecated. Please switch to GetRootAs.""" | STRING |
| MEDIUM | onnxruntime/test/testdata/icm-31000000518483.py | 20 | # Create the main graph | COMMENT |
| MEDIUM | onnxruntime/test/testdata/ort_github_issue_10305.py | 22 | # Create the main graph | COMMENT |
| MEDIUM | …xruntime/test/testdata/test_arbitrary_external_file.py | 46 | # Create the model | COMMENT |
| MEDIUM | onnxruntime/test/testdata/ort_github_issue_26272.py | 4 | # Create a simple ONNX model with DDS output | COMMENT |
| 197 more matches not shown… | ||||
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| HIGH | …rs/ort_flatbuffers_py/fbs/RuntimeOptimizationRecord.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …/ort_flatbuffers_py/fbs/DeprecatedKernelCreateInfos.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …ffers/ort_flatbuffers_py/fbs/NodesToOptimizeIndices.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …e/core/flatbuffers/ort_flatbuffers_py/fbs/Attribute.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …ore/flatbuffers/ort_flatbuffers_py/fbs/SequenceType.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …ffers/ort_flatbuffers_py/fbs/DeprecatedSessionState.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …flatbuffers/ort_flatbuffers_py/fbs/InferenceSession.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …/core/flatbuffers/ort_flatbuffers_py/fbs/Checkpoint.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …e/flatbuffers/ort_flatbuffers_py/fbs/OptimizerGroup.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …re/flatbuffers/ort_flatbuffers_py/fbs/OperatorSetId.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …core/flatbuffers/ort_flatbuffers_py/fbs/PropertyBag.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …e/core/flatbuffers/ort_flatbuffers_py/fbs/ValueInfo.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …buffers/ort_flatbuffers_py/fbs/RuntimeOptimizations.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …s/ort_flatbuffers_py/fbs/OpIdKernelTypeStrArgsEntry.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …ntime/core/flatbuffers/ort_flatbuffers_py/fbs/Graph.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …ime/core/flatbuffers/ort_flatbuffers_py/fbs/MapType.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …atbuffers/ort_flatbuffers_py/fbs/TensorTypeAndShape.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …fers/ort_flatbuffers_py/fbs/ParameterOptimizerState.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …ore/flatbuffers/ort_flatbuffers_py/fbs/SparseTensor.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …fers_py/fbs/RuntimeOptimizationRecordContainerEntry.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …e/flatbuffers/ort_flatbuffers_py/fbs/DimensionValue.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …me/core/flatbuffers/ort_flatbuffers_py/fbs/TypeInfo.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …uffers/ort_flatbuffers_py/fbs/KernelTypeStrResolver.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …ntime/core/flatbuffers/ort_flatbuffers_py/fbs/Model.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …time/core/flatbuffers/ort_flatbuffers_py/fbs/Tensor.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …t_flatbuffers_py/fbs/DeprecatedSubGraphSessionState.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …tbuffers_py/fbs/DeprecatedNodeIndexAndKernelDefHash.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …latbuffers/ort_flatbuffers_py/fbs/StringStringEntry.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …me/core/flatbuffers/ort_flatbuffers_py/fbs/NodeEdge.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …ntime/core/flatbuffers/ort_flatbuffers_py/fbs/Shape.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …e/flatbuffers/ort_flatbuffers_py/fbs/StringProperty.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …core/flatbuffers/ort_flatbuffers_py/fbs/ModuleState.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …untime/core/flatbuffers/ort_flatbuffers_py/fbs/Node.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …re/flatbuffers/ort_flatbuffers_py/fbs/FloatProperty.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …ffers/ort_flatbuffers_py/fbs/KernelTypeStrArgsEntry.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …/flatbuffers/ort_flatbuffers_py/fbs/ArgTypeAndIndex.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …core/flatbuffers/ort_flatbuffers_py/fbs/IntProperty.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …e/core/flatbuffers/ort_flatbuffers_py/fbs/Dimension.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …hon/tools/quantization/CalTableFlatBuffers/TrtTable.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | …hon/tools/quantization/CalTableFlatBuffers/KeyValue.py | 0 | this method is deprecated. please switch to getrootas. | STRING |
| HIGH | onnxruntime/test/testdata/packed_attention_fp16.rbp.py | 0 | run this script to recreate the original onnx model. example usage: python matmulnbits_add_gen.py out_model_path.onnx | STRING |
| HIGH | onnxruntime/test/testdata/abs_0d_lostdim.py | 0 | run this script to recreate the original onnx model. example usage: python matmulnbits_add_gen.py out_model_path.onnx | STRING |
| HIGH | onnxruntime/test/testdata/abs_0d_input.py | 0 | run this script to recreate the original onnx model. example usage: python matmulnbits_add_gen.py out_model_path.onnx | STRING |
| HIGH | …/transform/runtime_optimization/matmulnbits_add_gen.py | 0 | run this script to recreate the original onnx model. example usage: python matmulnbits_add_gen.py out_model_path.onnx | STRING |
| HIGH | …ation/lr_scheduler/lr_scheduler_test_data_generator.py | 0 | a dummy module containing only one trainable parameter. | STRING |
| HIGH | …ata_generation/adamw_test/adamw_test_data_generator.py | 0 | a dummy module containing only one trainable parameter. | STRING |
| HIGH | …st_data_generation/sgd_test/sgd_test_data_generator.py | 0 | a dummy module containing only one trainable parameter. | STRING |
| HIGH | onnxruntime/test/python/quantization/test_onnx_model.py | 0 | helper function to generate initializers for test inputs | STRING |
| HIGH | onnxruntime/test/python/quantization/op_test_utils.py | 0 | helper function to generate initializers for test inputs | STRING |
| HIGH | …xruntime/test/python/quantization/test_conv_dynamic.py | 0 | helper function to generate initializers for test inputs | STRING |
| HIGH | onnxruntime/test/python/quantization/test_qdq.py | 0 | helper function to generate initializers for test inputs | STRING |
| HIGH | …nxruntime/test/python/quantization/test_calibration.py | 0 | helper function to generate initializers for test inputs | STRING |
| HIGH | onnxruntime/test/python/transformers/test_gqa.py | 0 | print percentile statistics (75%, 95%, 99%) for a difference tensor. this helps assess parity quality beyond just max di | STRING |
| HIGH | onnxruntime/test/python/transformers/test_qmoe_cuda.py | 0 | print percentile statistics (75%, 95%, 99%) for a difference tensor. this helps assess parity quality beyond just max di | STRING |
| HIGH | onnxruntime/test/python/transformers/test_moe_cuda.py | 0 | print percentile statistics (75%, 95%, 99%) for a difference tensor. this helps assess parity quality beyond just max di | STRING |
| HIGH | …test/python/transformers/test_onnx_attention/common.py | 0 | print percentile statistics (75%, 95%, 99%) for a difference tensor. this helps assess parity quality beyond just max di | STRING |
| HIGH | onnxruntime/test/python/transformers/benchmark_qmoe.py | 0 | benchmark tests for qmoe swiglu performance measurement. | STRING |
| HIGH | onnxruntime/test/python/transformers/test_qmoe_cuda.py | 0 | benchmark tests for qmoe swiglu performance measurement. | STRING |
| HIGH | onnxruntime/test/python/transformers/test_qmoe_cpu.py | 0 | benchmark tests for qmoe swiglu performance measurement. | STRING |
| HIGH | onnxruntime/test/python/transformers/benchmark_qmoe.py | 0 | comprehensive throughput benchmark for qmoe swiglu across different configurations. | STRING |
| 44 more matches not shown… | ||||
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| LOW | setup.py | 834 | CODE | |
| LOW | tools/ci_build/build.py | 156 | CODE | |
| LOW | tools/ci_build/build.py | 323 | CODE | |
| LOW | tools/ci_build/build.py | 1325 | CODE | |
| LOW | tools/ci_build/build.py | 1689 | CODE | |
| LOW | tools/ci_build/build.py | 1903 | CODE | |
| LOW | tools/ci_build/build.py | 1923 | CODE | |
| LOW | tools/ci_build/build.py | 2006 | CODE | |
| LOW | tools/ci_build/build.py | 2280 | CODE | |
| LOW | tools/ci_build/op_registration_utils.py | 123 | CODE | |
| LOW | tools/ci_build/compile_triton.py | 22 | CODE | |
| LOW | tools/ci_build/manage_java_artifacts.py | 109 | CODE | |
| LOW | tools/ci_build/linux_java_copy_strip_binary.py | 74 | CODE | |
| LOW | tools/ci_build/build_args.py | 41 | CODE | |
| LOW | tools/ci_build/build_args.py | 895 | CODE | |
| LOW | tools/ci_build/reduce_op_kernels.py | 234 | CODE | |
| LOW | tools/ci_build/cuda_plugin_parity_report.py | 100 | CODE | |
| LOW | tools/ci_build/cuda_plugin_parity_report.py | 167 | CODE | |
| LOW | tools/ci_build/cuda_plugin_parity_report.py | 212 | CODE | |
| LOW | tools/ci_build/set_plugin_ep_build_variables.py | 21 | CODE | |
| LOW | tools/ci_build/github/apple/test_apple_packages.py | 22 | CODE | |
| LOW | …build/github/windows/post_binary_sizes_to_dashboard.py | 41 | CODE | |
| LOW | tools/ci_build/github/windows/sign_java_artifacts.py | 12 | CODE | |
| LOW | tools/ci_build/github/windows/sign_java_artifacts.py | 25 | CODE | |
| LOW | tools/python/compile_contributors.py | 79 | CODE | |
| LOW | tools/python/compile_contributors.py | 184 | CODE | |
| LOW | tools/python/compile_contributors.py | 317 | CODE | |
| LOW | tools/python/update_ctest_path.py | 17 | CODE | |
| LOW | tools/python/run_android_emulator.py | 57 | CODE | |
| LOW | tools/python/cherry_pick_utils.py | 9 | CODE | |
| LOW | tools/python/create_reduced_build_config.py | 21 | CODE | |
| LOW | tools/python/create_reduced_build_config.py | 76 | CODE | |
| LOW | tools/python/run_packaging_pipelines.py | 114 | CODE | |
| LOW | tools/python/run_packaging_pipelines.py | 374 | CODE | |
| LOW | tools/python/sparsify_initializers.py | 57 | CODE | |
| LOW | tools/python/gen_contrib_doc.py | 90 | CODE | |
| LOW | tools/python/gen_contrib_doc.py | 115 | CODE | |
| LOW | tools/python/gen_contrib_doc.py | 306 | CODE | |
| LOW | tools/python/dump_ort_model.py | 41 | CODE | |
| LOW | tools/python/dump_ort_model.py | 86 | CODE | |
| LOW | tools/python/run_workflows_for_branch.py | 23 | CODE | |
| LOW | tools/python/gen_opkernel_doc.py | 96 | CODE | |
| LOW | tools/python/example_operator_perf_test.py | 72 | CODE | |
| LOW | tools/python/resolve_absl_deps_dynamic.py | 86 | CODE | |
| LOW | tools/python/fix_long_lines.py | 17 | CODE | |
| LOW | tools/python/benchmark_mmap_ort.py | 88 | CODE | |
| LOW | tools/python/benchmark_mmap_ort.py | 182 | CODE | |
| LOW | tools/python/benchmark_mmap_ort.py | 317 | CODE | |
| LOW | tools/python/ort_test_dir_utils.py | 25 | CODE | |
| LOW | tools/python/ort_test_dir_utils.py | 74 | CODE | |
| LOW | tools/python/ort_test_dir_utils.py | 194 | CODE | |
| LOW | tools/python/ort_test_dir_utils.py | 117 | CODE | |
| LOW | tools/python/onnx2tfevents.py | 262 | CODE | |
| LOW | tools/python/onnx2tfevents.py | 290 | CODE | |
| LOW | tools/python/onnx2tfevents.py | 303 | CODE | |
| LOW | tools/python/onnx2tfevents.py | 324 | CODE | |
| LOW | tools/python/cherry_pick.py | 85 | CODE | |
| LOW | tools/python/cherry_pick.py | 147 | CODE | |
| LOW | …ython/find_optimizer_opset_version_updates_required.py | 32 | CODE | |
| LOW | …ython/find_optimizer_opset_version_updates_required.py | 65 | CODE | |
| 490 more matches not shown… | ||||
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| LOW | tools/ci_build/build.py | 5 | CODE | |
| LOW | tools/ci_build/build.py | 1799 | CODE | |
| LOW | tools/ci_build/build.py | 1885 | CODE | |
| LOW | tools/ci_build/build.py | 1886 | CODE | |
| LOW | tools/ci_build/op_registration_utils.py | 8 | CODE | |
| LOW | tools/ci_build/update_tsaoptions.py | 3 | CODE | |
| LOW | tools/ci_build/set-trigger-rules.py | 7 | CODE | |
| LOW | tools/ci_build/patch_manylinux.py | 4 | CODE | |
| LOW | tools/ci_build/reduce_op_kernels.py | 4 | CODE | |
| LOW | …ols/ci_build/upload_python_package_to_azure_storage.py | 4 | CODE | |
| LOW | tools/ci_build/op_registration_validator.py | 8 | CODE | |
| LOW | tools/ci_build/github/apple/package_release_tasks.py | 5 | CODE | |
| LOW | tools/ci_build/github/apple/build_apple_framework.py | 5 | CODE | |
| LOW | …ols/ci_build/github/apple/get_simulator_device_info.py | 5 | CODE | |
| LOW | tools/ci_build/github/apple/build_settings_utils.py | 1 | CODE | |
| LOW | tools/python/wgsl_gen.py | 22 | CODE | |
| LOW | tools/python/run_android_emulator.py | 4 | CODE | |
| LOW | tools/python/run_adb.py | 4 | CODE | |
| LOW | tools/python/sparsify_initializers.py | 8 | CODE | |
| LOW | tools/python/gen_contrib_doc.py | 15 | CODE | |
| LOW | tools/python/gen_opkernel_doc.py | 6 | CODE | |
| LOW | tools/python/resolve_absl_deps_dynamic.py | 4 | CODE | |
| LOW | tools/python/trigger_and_wait_pipelines.py | 4 | CODE | |
| LOW | tools/python/util/run.py | 3 | CODE | |
| LOW | tools/python/util/get_azcopy.py | 3 | CODE | |
| LOW | tools/python/util/make_dynamic_shape_fixed.py | 4 | CODE | |
| LOW | tools/python/util/optimize_onnx_model.py | 4 | CODE | |
| LOW | tools/python/util/onnx_model_utils.py | 3 | CODE | |
| LOW | tools/python/util/__init__.py | 4 | CODE | |
| LOW | tools/python/util/__init__.py | 6 | CODE | |
| LOW | tools/python/util/__init__.py | 6 | CODE | |
| LOW | tools/python/util/__init__.py | 6 | CODE | |
| LOW | tools/python/util/__init__.py | 7 | CODE | |
| LOW | tools/python/util/__init__.py | 8 | CODE | |
| LOW | tools/python/util/__init__.py | 9 | CODE | |
| LOW | tools/python/util/__init__.py | 9 | CODE | |
| LOW | tools/python/util/__init__.py | 9 | CODE | |
| LOW | tools/python/util/__init__.py | 9 | CODE | |
| LOW | tools/python/util/__init__.py | 9 | CODE | |
| LOW | tools/python/util/__init__.py | 18 | CODE | |
| LOW | tools/python/util/__init__.py | 20 | CODE | |
| LOW | tools/python/util/__init__.py | 29 | CODE | |
| LOW | tools/python/util/reduced_build_config_parser.py | 3 | CODE | |
| LOW | tools/python/util/reduced_build_config_parser.py | 9 | CODE | |
| LOW | tools/python/util/__init__append.py | 6 | CODE | |
| LOW | tools/python/util/convert_onnx_models_to_ort.py | 5 | CODE | |
| LOW | tools/python/util/file_utils.py | 3 | CODE | |
| LOW | tools/python/util/pytorch_export_helpers.py | 4 | CODE | |
| LOW | tools/python/util/mobile_helpers/usability_checker.py | 3 | CODE | |
| LOW | …hon/util/mobile_helpers/test/test_usability_checker.py | 3 | CODE | |
| LOW | …til/ort_format_model/operator_type_usage_processors.py | 3 | CODE | |
| LOW | tools/python/util/ort_format_model/__init__.py | 21 | CODE | |
| LOW | tools/python/util/ort_format_model/__init__.py | 21 | CODE | |
| LOW | tools/python/util/ort_format_model/__init__.py | 21 | CODE | |
| LOW | tools/python/util/ort_format_model/__init__.py | 26 | CODE | |
| LOW | tools/python/util/ort_format_model/__init__.py | 27 | CODE | |
| LOW | tools/python/util/android/__init__.py | 4 | CODE | |
| LOW | tools/python/util/android/__init__.py | 4 | CODE | |
| LOW | tools/python/util/android/__init__.py | 4 | CODE | |
| LOW | tools/python/util/android/__init__.py | 4 | CODE | |
| 346 more matches not shown… | ||||
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| MEDIUM | setup.py | 337 | print("Error importing dependencies:") | CODE |
| LOW | setup.py | 765 | except Exception: | CODE |
| LOW | setup.py | 776 | except Exception: | CODE |
| MEDIUM | setup.py | 761 | def check_date_format(date_str): | CODE |
| MEDIUM | setup.py | 768 | def reformat_run_count(count_str): | CODE |
| MEDIUM | tools/ci_build/build.py | 1918 | print(f"Error decoding JSON from version.json in {cuda_home}.") | CODE |
| LOW | tools/ci_build/prepare_macos_package.py | 183 | except Exception as e: | CODE |
| LOW | tools/ci_build/linux_java_copy_strip_binary.py | 195 | except Exception as e: | CODE |
| LOW | tools/ci_build/build_args.py | 422 | except Exception as e: | CODE |
| LOW | tools/ci_build/cuda_plugin_parity_report.py | 560 | except Exception as e: | CODE |
| MEDIUM | tools/ci_build/cuda_plugin_parity_report.py | 562 | print(f"Error: failed to register plugin EP '{plugin_ep_name}': {e}", file=sys.stderr) | CODE |
| MEDIUM | tools/ci_build/cuda_plugin_parity_report.py | 692 | print("Error: Could not find repo root. Use --repo-root flag.", file=sys.stderr) | CODE |
| LOW | tools/ci_build/set_plugin_ep_build_variables.py | 77 | except Exception as e: | CODE |
| LOW | tools/ci_build/github/windows/sign_java_artifacts.py | 73 | except Exception as e: | CODE |
| MEDIUM | tools/ci_build/github/windows/sign_java_artifacts.py | 74 | print(f"Error generating {algorithm} hash for {file_path}: {e}") | CODE |
| MEDIUM | tools/ci_build/github/windows/sign_java_artifacts.py | 88 | print(f"Error: Directory not found at '{jar_file_directory}'", file=sys.stderr) | CODE |
| MEDIUM | tools/ci_build/github/windows/sign_java_artifacts.py | 110 | print(f"Error: GPG executable not found at '{gpg_exe_path}'.", file=sys.stderr) | CODE |
| MEDIUM | tools/ci_build/github/windows/jar_packaging.py | 23 | print("Error: The 'semver' package is not installed. Please add it to your requirements.txt.", file=sys.stderr) | CODE |
| MEDIUM | tools/ci_build/github/windows/jar_packaging.py | 75 | print(f"Error: 7z failed to archive '{file_to_add.name}' to '{archive_path.name}'.", file=sys.stderr) | CODE |
| MEDIUM | tools/ci_build/github/windows/jar_packaging.py | 102 | print(f"Error: 7z failed to archive directory '{source_dir.name}' to '{archive_path.name}'.", file=sys.stderr) | CODE |
| MEDIUM | tools/ci_build/github/windows/jar_packaging.py | 121 | print(f"Error: Version '{version_string}' is not valid. Reason: {e}", file=sys.stderr) | CODE |
| MEDIUM | tools/ci_build/github/windows/jar_packaging.py | 135 | print(f"Error: Missing companion sources JAR. Expected: {sources_jar_path.name}", file=sys.stderr) | CODE |
| MEDIUM | tools/ci_build/github/windows/jar_packaging.py | 139 | print(f"Error: Missing companion javadoc JAR. Expected file like: {base_stem}-javadoc.jar", file=sys.stderr) | CODE |
| MEDIUM | tools/ci_build/github/windows/jar_packaging.py | 167 | print(f"Error: Expected custom op library '{custom_lib_file}' not found in {platform_path}", file=sys.stderr) | CODE |
| MEDIUM | tools/ci_build/github/windows/jar_packaging.py | 189 | print(f"Error: Primary package directory not found at '{primary_package_dir}'", file=sys.stderr) | CODE |
| MEDIUM | tools/ci_build/github/windows/jar_packaging.py | 252 | print(f"Error: Base 'testing.jar' not found at '{final_test_archive}'.", file=sys.stderr) | CODE |
| MEDIUM | tools/ci_build/github/windows/jar_packaging.py | 260 | print(f"Error: Required platform artifact directory not found: {platform_full_path}", file=sys.stderr) | CODE |
| MEDIUM | tools/ci_build/github/windows/jar_packaging.py | 277 | print("Error: This script is intended to be run on Windows.", file=sys.stderr) | CODE |
| LOW | tools/ci_build/github/windows/jar_packaging.py | 312 | except Exception as e: | CODE |
| MEDIUM⚡ | tools/python/update_version.py | 120 | print("Error: Could not import 'is_windows' and 'run' from a 'util' module.", file=sys.stderr) | CODE |
| MEDIUM⚡ | tools/python/update_version.py | 134 | print(f"Error: 'fnm' is being used, but the version file '{nvmrc_path}' was not found.", file=sys.stderr) | CODE |
| MEDIUM | tools/python/update_version.py | 151 | print("Error: Could not find 'node' and 'npm' in your PATH.", file=sys.stderr) | CODE |
| MEDIUM | tools/python/update_version.py | 195 | print(f"Error: '{version_file}' not found.", file=sys.stderr) | CODE |
| MEDIUM | tools/python/update_ctest_path.py | 52 | print(f"Error: Could not find old source/build directory paths in {file_path}", file=sys.stderr) | CODE |
| MEDIUM | tools/python/update_ctest_path.py | 86 | print(f"Error during file processing: {e}", file=sys.stderr) | CODE |
| MEDIUM | tools/python/update_ctest_path.py | 93 | print(f"Error replacing file: {e}", file=sys.stderr) | CODE |
| MEDIUM | tools/python/update_ctest_path.py | 121 | print(f"Error: CTest file not found at '{args.ctest_file}'", file=sys.stderr) | CODE |
| LOW | tools/python/update_ctest_path.py | 126 | except Exception as e: | CODE |
| MEDIUM⚡ | tools/python/cherry_pick_utils.py | 16 | print(f"Error running command: {log_str}", file=sys.stderr) | CODE |
| MEDIUM⚡ | tools/python/cherry_pick_utils.py | 24 | print(f"Error: '{cmd}' command not found.", file=sys.stderr) | CODE |
| LOW⚡ | tools/python/cherry_pick_utils.py | 31 | except Exception as e: | CODE |
| MEDIUM | tools/python/cherry_pick_utils.py | 42 | print("Error: This script must be run inside a git repository.", file=sys.stderr) | CODE |
| MEDIUM | tools/python/cherry_pick_utils.py | 48 | print("Error: GitHub CLI (gh) not found or not in PATH.", file=sys.stderr) | CODE |
| MEDIUM⚡ | tools/python/cherry_pick_utils.py | 60 | print("Error: GitHub CLI not authenticated. Please run 'gh auth login'.", file=sys.stderr) | CODE |
| MEDIUM⚡ | tools/python/cherry_pick_utils.py | 63 | print("Error: GitHub CLI (gh) not found.", file=sys.stderr) | CODE |
| LOW | tools/python/run_packaging_pipelines.py | 93 | except Exception as e: | CODE |
| LOW | tools/python/run_packaging_pipelines.py | 260 | except Exception as e: | CODE |
| LOW | tools/python/gen_opkernel_doc.py | 84 | except Exception as e: | CODE |
| LOW | tools/python/gen_opkernel_doc.py | 90 | except Exception as e: | CODE |
| MEDIUM | tools/python/resolve_absl_deps_dynamic.py | 184 | print(f"Error: Failed to download Abseil version '{version}'.", file=sys.stderr) | CODE |
| MEDIUM | tools/python/resolve_absl_deps_dynamic.py | 226 | print(f"Error: Input file '{args.input_file}' not found.", file=sys.stderr) | CODE |
| MEDIUM | tools/python/resolve_absl_deps_dynamic.py | 241 | print(f"An error occurred during resolution: {e}", file=sys.stderr) | CODE |
| LOW | tools/python/trigger_and_wait_pipelines.py | 320 | except Exception as e: | CODE |
| LOW | tools/python/PythonTools.md | 168 | except Exception: | CODE |
| MEDIUM | tools/python/cherry_pick.py | 63 | print(f"Error parsing gh output: {e}", file=sys.stderr) | CODE |
| LOW | tools/python/util/convert_onnx_models_to_ort.py | 171 | except Exception as e: | CODE |
| MEDIUM | tools/python/util/convert_onnx_models_to_ort.py | 172 | print(f"Error converting {model}: {e}") | CODE |
| LOW | tools/python/wgsl_template/test/test_in_tree_smoke.py | 58 | except Exception: | CODE |
| LOW | tools/python/wgsl_template/test/test_parser.py | 267 | except Exception as e: | CODE |
| LOW | tools/python/wgsl_template/test/test_generator.py | 239 | except Exception as e: | CODE |
| 166 more matches not shown… | ||||
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| MEDIUM | tools/ci_build/manage_java_artifacts.py | 84 | # Adding these makes the command more robust and less prone to errors | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 1272 | # it is more robust and this tag (HTML_STYLESHEET) will in the future become | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 1282 | # standard style sheet and is therefore more robust against future updates. | COMMENT |
| MEDIUM | …thub/azure-pipelines/py-cuda-package-test-pipeline.yml | 11 | # To utilize gpu resource more efficiently, run GPU job only after all cpus jobs succeed | COMMENT |
| MEDIUM | tools/python/wgsl_template/test/test_parser.py | 236 | # and need a different harness. | COMMENT |
| MEDIUM | onnxruntime/core/mickey/blk_q4/f16_gemm_sm80.h | 46 | // We pack 4 weights into one 16b element, so as to leverage cutlass tile iterators | COMMENT |
| MEDIUM | onnxruntime/core/mickey/blk_q4/f16_prepack_sm80.h | 51 | // We pack 4 weights into one 16b element, so we can leverage cutlass tile iterators | COMMENT |
| MEDIUM | …emm/threadblock/optional_predicated_tile_access_iter.h | 28 | /// iterator becomes no-op with minimal runtime footprint. Also, it utilize the | COMMENT |
| MEDIUM | …emm/threadblock/optional_predicated_tile_access_iter.h | 29 | /// higher numbered threads in the threadblock when the iterator can not utilize | COMMENT |
| MEDIUM | …emm/threadblock/optional_predicated_tile_access_iter.h | 43 | /// will utilize the higher numbered threads | COMMENT |
| MEDIUM | …q4gemm/threadblock/optional_regular_tile_access_iter.h | 35 | /// becomes no-op with minimal runtime footprint. Also, it utilize the higher | COMMENT |
| MEDIUM | …q4gemm/threadblock/optional_regular_tile_access_iter.h | 36 | /// numbered threads in the threadblock when the iterator can not utilize all | COMMENT |
| MEDIUM | …q4gemm/threadblock/optional_regular_tile_access_iter.h | 47 | /// will utilize the higher numbered threads | COMMENT |
| MEDIUM | onnxruntime/core/mickey/gemm/kernel/quant_b4_gemm.h | 121 | // Need 4 tiles to fully utilize ldmatrix. And..... | COMMENT |
| MEDIUM | onnxruntime/core/mickey/gemm/kernel/quant_b4_gemm.h | 151 | // to load 4 tiles, fully utilize the ldmatrix instruction. | COMMENT |
| MEDIUM | onnxruntime/core/mickey/gemm/kernel/quant_b4_gemm.h | 736 | using Float4 = cutlass::Array<float, 4>; // hopefully utilize 128b st.shared.b128 | CODE |
| MEDIUM | …nxruntime/core/framework/prepacked_weights_container.h | 117 | // Reference in this context means a non-owning smart pointer. Essentially, this function | COMMENT |
| MEDIUM | …ovider/src/Operators/DmlOperatorBatchNormalization.cpp | 89 | // and normally we'd need to specify kernelInputIndices to Initialize, but we'll utilize DMLX's mapping instead. | COMMENT |
| MEDIUM | onnxruntime/core/mlas/lib/flashattn.cpp | 145 | // TODO: leverage advanced instruction sets | COMMENT |
| MEDIUM | onnxruntime/core/mlas/lib/halfgemm.cpp | 383 | // Without PackB, to utilize memory locality, iterate full K. | COMMENT |
| MEDIUM | onnxruntime/core/mlas/lib/activate_fp16.cpp | 172 | // leverage the fact that for our implementation tanhf(sat_cutoff) == -1.0h. NaN inputs are | COMMENT |
| MEDIUM | onnxruntime/core/mlas/lib/activate_fp16.cpp | 238 | // leverage the fact that for our implementation tanhf(sat_cutoff) == -1.0h. NaN inputs are | COMMENT |
| MEDIUM | onnxruntime/test/python/transformers/test_gqa.py | 1991 | # For past test: pipeline tests share_buffer=True only, comprehensive tests both | COMMENT |
| MEDIUM | onnxruntime/test/python/transformers/test_gqa.py | 2077 | # The past-parity harness compares the full present buffer; without buffer | COMMENT |
| MEDIUM | onnxruntime/test/python/transformers/test_mha.py | 214 | # Lengths of arrays are prime numbers since modulo (% length) is used in non comprehensive mode. | COMMENT |
| MEDIUM | onnxruntime/test/python/transformers/test_mha.py | 310 | # Lengths of arrays are prime numbers since modulo (% length) is used in non comprehensive mode. | COMMENT |
| MEDIUM | onnxruntime/test/unittest_util/qdq_test_utils.h | 622 | // Essentially eveything has worked correctly if the DQ -> Transpose -> Q becomes a single Transpose and the | COMMENT |
| LOW | onnxruntime/python/tools/quantization/base_quantizer.py | 410 | # axis, symmetric, and reduce_range values. So, just use the first channel's values. | COMMENT |
| LOW | …time/python/tools/quantization/operators/activation.py | 19 | # If activation is symmetric, not quantize the op and simply return | COMMENT |
| MEDIUM | …untime/python/tools/transformers/convert_generation.py | 2630 | # dims need to be a multiple of 8 to leverage tensor cores. | COMMENT |
| MEDIUM | …els/torch_export_patches/patches/patch_transformers.py | 358 | # (this alternative is not as robust as calling | COMMENT |
| MEDIUM | onnxruntime/python/tools/tensorrt/perf/benchmark.py | 336 | if with_binding and cpu not in ep: # other eps utilize python binding | CODE |
| MEDIUM | …ng/test/python/orttraining_test_ort_pipeline_module.py | 32 | """Custom dataset to facilitate loading and batching of data.""" | STRING |
| MEDIUM | …ing/orttraining/python/training/ortmodule/ortmodule.py | 31 | """Extends user's :class:`torch.nn.Module` model to leverage ONNX Runtime super fast training engine. | STRING |
| MEDIUM | …n/training/ortmodule/_gradient_accumulation_manager.py | 73 | # TODO: Make detection of parameter update robust | COMMENT |
| MEDIUM | …python/training/ortmodule/_graph_transition_manager.py | 378 | # forward run. To facilitate un-flattening during subsequent ORT runs, the output schema is saved as | COMMENT |
| LOW | …ng/ortmodule/experimental/pipe/_ort_pipeline_module.py | 162 | # that case and just use it in forward() | COMMENT |
| MEDIUM | …hon/training/ortmodule/torch_cpp_extensions/install.py | 64 | # Extensions might leverage CUDA versions internally | COMMENT |
| LOW | …ython/training/utils/hooks/_zero_offload_subscriber.py | 394 | # STAGE3WARN#3: _post_forward_module_hook's second argument `input is not used, so we just pass a None here. | COMMENT |
| LOW | …ython/training/utils/hooks/_zero_offload_subscriber.py | 611 | # STAGE3WARN#7: _pre_backward_module_hook's second argument `input is not used, so we just pass a None here. | COMMENT |
| LOW⚡ | …g/orttraining/python/training/ort_triton/_decompose.py | 342 | # The decompose process will be called recursively, if it's already a decomposed result, just return. | COMMENT |
| LOW⚡ | …g/orttraining/python/training/ort_triton/_decompose.py | 349 | # The decompose process will be called recursively, if it's already a decomposed result, just return. | COMMENT |
| LOW⚡ | …g/orttraining/python/training/ort_triton/_decompose.py | 353 | # The decompose process will be called recursively, if it's already a decomposed result, just return. | COMMENT |
| LOW | …ining/python/training/ort_triton/kernel/_flash_attn.py | 135 | # [2022-10-30] TD: Triton bug - in the case of EVEN_M=True and EVEN_N=False, if we just call | COMMENT |
| LOW | …ining/python/training/ort_triton/kernel/_flash_attn.py | 321 | # if we just call tl.store(dv_ptrs), there's a race condition | COMMENT |
| LOW | …ining/python/training/ort_triton/kernel/_flash_attn.py | 416 | # if we just call tl.load(k_ptrs), we get the wrong output! | COMMENT |
| LOW | …ining/python/training/ort_triton/kernel/_flash_attn.py | 491 | # [2022-11-01] TD: Triton bug, there's a race condition if we just use m_mask and not d_mask. | COMMENT |
| MEDIUM | include/onnxruntime/core/framework/float4.h | 5 | // if they would like to leverage the CUDA implementation for the conversion routines | COMMENT |
| MEDIUM | include/onnxruntime/core/platform/threadpool.h | 87 | // dynamic balancing behavior helps make performance robust to any | COMMENT |
| MEDIUM | include/onnxruntime/core/common/float8.h | 5 | // if they would like to leverage the CUDA implementation for the conversion routines | COMMENT |
| MEDIUM | winml/lib/Api/LearningModelSession.h | 70 | // LearningModelBinding needs to leverage the lock | COMMENT |
| MEDIUM⚡ | …ocs/_exported_templates/default/styles/docfx.vendor.js | 1 | !function(e,t){"use strict";"object"==typeof module&&"object"==typeof module.exports?module.exports=e.document?t(e,!0):f | CODE |
| MEDIUM⚡ | …ocs/_exported_templates/default/styles/docfx.vendor.js | 1 | !function(e,t){"use strict";"object"==typeof module&&"object"==typeof module.exports?module.exports=e.document?t(e,!0):f | CODE |
| MEDIUM⚡ | …ocs/_exported_templates/default/styles/docfx.vendor.js | 1 | !function(e,t){"use strict";"object"==typeof module&&"object"==typeof module.exports?module.exports=e.document?t(e,!0):f | CODE |
| MEDIUM | …arp/src/Microsoft.ML.OnnxRuntime/OrtEpDevice.shared.cs | 52 | /// that the execution provider can utilize. | COMMENT |
| MEDIUM | …arp/src/Microsoft.ML.OnnxRuntime/OrtEpDevice.shared.cs | 114 | /// The hardware device that the execution provider can utilize. | COMMENT |
| MEDIUM | csharp/src/Microsoft.ML.OnnxRuntime/OrtEnv.shared.cs | 706 | /// Devices the execution provider can utilize are added to the values returned by GetEpDevices() and can | COMMENT |
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| LOW | tools/ci_build/compile_triton.py | 25 | CODE | |
| LOW | …ols/ci_build/github/apple/get_simulator_device_info.py | 142 | CODE | |
| LOW | tools/python/util/run.py | 13 | CODE | |
| LOW | …ation/lr_scheduler/lr_scheduler_test_data_generator.py | 40 | CODE | |
| LOW | …ata_generation/adamw_test/adamw_test_data_generator.py | 20 | CODE | |
| LOW | …ata_generation/adamw_test/adamw_test_data_generator.py | 37 | CODE | |
| LOW | …st_data_generation/sgd_test/sgd_test_data_generator.py | 20 | CODE | |
| LOW | …st_data_generation/sgd_test/sgd_test_data_generator.py | 37 | CODE | |
| LOW | …/transform/recompute/recompute_test_graph_generator.py | 27 | CODE | |
| LOW | …/testdata/training_api/ort_format/prepare_artifacts.py | 25 | CODE | |
| LOW | …runtime/test/python/test_pytorch_export_contrib_ops.py | 65 | CODE | |
| LOW | …nxruntime/test/python/onnxruntime_test_float8_gemm8.py | 27 | CODE | |
| LOW | …ntime/test/python/quantization/test_quantize_static.py | 104 | CODE | |
| LOW | onnxruntime/test/python/transformers/test_gqa.py | 919 | CODE | |
| LOW | onnxruntime/test/python/transformers/profile_gqa.py | 61 | CODE | |
| LOW | …untime/test/python/transformers/test_mha_flash_attn.py | 282 | CODE | |
| LOW | …untime/test/python/transformers/test_mha_flash_attn.py | 300 | CODE | |
| LOW | …time/test/python/transformers/qwen3_model_generator.py | 298 | CODE | |
| LOW | onnxruntime/test/python/transformers/test_gqa_cpu.py | 152 | CODE | |
| LOW | onnxruntime/test/python/transformers/test_gqa_cpu.py | 393 | CODE | |
| LOW | onnxruntime/test/python/transformers/test_gqa_cpu.py | 777 | CODE | |
| LOW | onnxruntime/test/python/transformers/test_gqa_cpu.py | 935 | CODE | |
| LOW | onnxruntime/test/python/transformers/test_gqa_cpu.py | 1158 | CODE | |
| LOW | onnxruntime/test/python/transformers/test_gqa_cpu.py | 1256 | CODE | |
| LOW | onnxruntime/test/python/transformers/test_gqa_cpu.py | 1324 | CODE | |
| LOW | onnxruntime/test/python/transformers/test_gqa_cpu.py | 1609 | CODE | |
| LOW | onnxruntime/test/python/transformers/test_gqa_cpu.py | 1869 | CODE | |
| LOW | onnxruntime/test/python/transformers/test_gqa_cpu.py | 2162 | CODE | |
| LOW | onnxruntime/test/python/transformers/benchmark_mha.py | 85 | CODE | |
| LOW | onnxruntime/test/python/transformers/test_qmoe_cuda.py | 266 | CODE | |
| LOW | onnxruntime/test/python/transformers/gqa_test_helper.py | 162 | CODE | |
| LOW | onnxruntime/test/python/transformers/gqa_test_helper.py | 288 | CODE | |
| LOW | onnxruntime/test/python/transformers/test_whisper.py | 220 | CODE | |
| LOW | …test/python/transformers/test_parity_neox_attention.py | 366 | CODE | |
| LOW | …/test/python/transformers/test_paged_attention_cuda.py | 343 | CODE | |
| LOW | …time/test/python/transformers/test_sparse_attention.py | 45 | CODE | |
| LOW | …ntime/test/python/transformers/gpt2_model_generator.py | 580 | CODE | |
| LOW | …ntime/test/python/transformers/gpt2_model_generator.py | 761 | CODE | |
| LOW | …/transformers/test_parity_huggingface_gpt_attention.py | 168 | CODE | |
| LOW | onnxruntime/test/python/transformers/test_moe_cuda.py | 1236 | CODE | |
| LOW | onnxruntime/test/python/transformers/test_qmoe_cpu.py | 388 | CODE | |
| LOW | …rs/test_onnx_attention/test_tensorscatter_attention.py | 144 | CODE | |
| LOW | onnxruntime/python/tools/quantization/quantize.py | 247 | CODE | |
| LOW | onnxruntime/python/tools/quantization/quantize.py | 509 | CODE | |
| LOW | onnxruntime/python/tools/quantization/quantize.py | 914 | CODE | |
| LOW | onnxruntime/python/tools/quantization/quantize.py | 44 | CODE | |
| LOW | onnxruntime/python/tools/quantization/quantize.py | 99 | CODE | |
| LOW | onnxruntime/python/tools/quantization/quantize.py | 431 | CODE | |
| LOW | …me/python/tools/quantization/static_quantize_runner.py | 42 | CODE | |
| LOW | …me/python/tools/quantization/matmul_nbits_quantizer.py | 142 | CODE | |
| LOW | …me/python/tools/quantization/matmul_nbits_quantizer.py | 236 | CODE | |
| LOW | …me/python/tools/quantization/matmul_nbits_quantizer.py | 1477 | CODE | |
| LOW | …nxruntime/python/tools/quantization/shape_inference.py | 25 | CODE | |
| LOW | onnxruntime/python/tools/quantization/calibrate.py | 169 | CODE | |
| LOW | onnxruntime/python/tools/quantization/calibrate.py | 384 | CODE | |
| LOW | onnxruntime/python/tools/quantization/calibrate.py | 624 | CODE | |
| LOW | …on/tools/quantization/neural_compressor/weight_only.py | 420 | CODE | |
| LOW | …on/tools/quantization/neural_compressor/weight_only.py | 604 | CODE | |
| LOW | …on/tools/quantization/neural_compressor/weight_only.py | 744 | CODE | |
| LOW | …ols/quantization/execution_providers/qnn/preprocess.py | 22 | CODE | |
| 95 more matches not shown… | ||||
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| LOW | tools/ci_build/prepare_macos_package.py | 34 | # Check if any part of the path is a .dSYM directory. | COMMENT |
| LOW | tools/ci_build/set-trigger-rules.py | 42 | # Open the file and read its lines | COMMENT |
| LOW | tools/ci_build/build_args.py | 987 | # Check if cmake_generator attribute exists (it might if --use_xcode was used) | STRING |
| LOW | …e-pipelines/templates/setup-feeds-and-python-steps.yml | 119 | # Check if python is available in PATH | COMMENT |
| LOW | …build/github/azure-pipelines/templates/setup-maven.yml | 23 | # Check if the download was successful | COMMENT |
| LOW | …build/github/azure-pipelines/templates/setup-maven.yml | 34 | # Check if the extraction was successful | COMMENT |
| LOW | …ls/ci_build/github/linux/build_linux_python_package.sh | 27 | # Check if OPTARG is empty or starts with a hyphen, indicating a missing or invalid argument for -p | COMMENT |
| LOW | …ls/ci_build/github/linux/build_linux_python_package.sh | 114 | # Check if the Python executable or its directory exists | COMMENT |
| LOW | …i_build/github/android/build_aar_and_copy_artifacts.sh | 30 | # Check if the include ops config file exists and modify command if it does | COMMENT |
| LOW⚡ | tools/python/update_version.py | 125 | # Check if node and npm are directly available in the system's PATH. | COMMENT |
| LOW | tools/python/compile_contributors.py | 216 | # Check if it's a cherry-pick round PR | COMMENT |
| LOW | tools/python/cherry_pick.py | 110 | # Check if it's a cherry-pick / meta-PR | COMMENT |
| LOW | tools/python/util/reduced_build_config_parser.py | 7 | # Check if the flatbuffers module is available. If not we cannot handle type reduction information in the config. | COMMENT |
| LOW⚡ | tools/python/util/android/android.py | 236 | # Verify if the emulator is now running | COMMENT |
| LOW | tools/python/wgsl_template/__init__.py | 97 | # Write files. Idempotent: only overwrite when content differs. | COMMENT |
| LOW | tools/nuget/generate_nuspec_for_native_nuget.py | 89 | # Check if the file has digits like onnxruntime.1.8.0.dylib. We can skip such things | COMMENT |
| LOW | tools/nuget/validate_package.py | 341 | # Check if the relevant dlls are present in the Nuget/Zip | COMMENT |
| LOW | tools/nuget/validate_package.py | 357 | # Check if the Nuget has been signed | COMMENT |
| LOW | onnxruntime/__init__.py | 404 | # Check if CUDA version is supported (12.x or 13.x+) | COMMENT |
| LOW | onnxruntime/__init__.py | 429 | # Check if torch CUDA version matches onnxruntime CUDA version | COMMENT |
| LOW | onnxruntime/test/testdata/dmmha_inside_mha_data.py | 171 | # Print values in format for onnxruntime/test/testdata/attention/attention_test_data.txt | COMMENT |
| LOW⚡ | …runtime/test/python/quantization/bench_matmul_8bits.py | 496 | # Print results to console | COMMENT |
| LOW⚡ | …runtime/test/python/quantization/bench_matmul_8bits.py | 663 | # Check if k is divisible by block_size for the single config case | COMMENT |
| LOW | …time/test/python/transformers/test_sparse_attention.py | 408 | # Check if the past_key_cache and new_key have compatible shapes | COMMENT |
| LOW | onnxruntime/test/common/test_cpuinfo_sysfs_fallback.py | 422 | # Check if onnxruntime is importable | STRING |
| LOW | onnxruntime/python/tools/layering/layer_annotate.py | 93 | # Check if annotation already exists | COMMENT |
| LOW | onnxruntime/python/tools/quantization/qdq_quantizer.py | 100 | # Check if consumer node name is in the list of nodes that | COMMENT |
| LOW | onnxruntime/python/tools/quantization/qdq_quantizer.py | 139 | # Check if consumer node name is in the list of nodes that | COMMENT |
| LOW | onnxruntime/python/tools/quantization/qdq_quantizer.py | 992 | # Check if this tensor is already a dequantized value. If so, skip it. | COMMENT |
| LOW | …me/python/tools/quantization/tensor_quant_overrides.py | 483 | # Check if all nodes receive the converted type (i.e., recv_nodes is None) or this node | COMMENT |
| LOW | …me/python/tools/transformers/fusion_qordered_matmul.py | 128 | # Check if weight 'B' is a constant | COMMENT |
| LOW | onnxruntime/python/tools/transformers/fusion_options.py | 70 | # Set default to sequence length for BERT model to use fused attention to speed up. | COMMENT |
| LOW | …e/python/tools/transformers/fusion_rotary_attention.py | 247 | # Check if first input to Add and Unsqueeze #1 is position ids | COMMENT |
| LOW | …e/python/tools/transformers/fusion_rotary_attention.py | 1373 | # Check if node is "RotaryEmbedding nn.Module" exported as a function | COMMENT |
| LOW | …ime/python/tools/transformers/fusion_attention_unet.py | 901 | # Check if we have a LoRA pattern | COMMENT |
| LOW | …xruntime/python/tools/transformers/fusion_layernorm.py | 58 | # Check if Sub --> Div exists | COMMENT |
| LOW | …xruntime/python/tools/transformers/fusion_layernorm.py | 64 | # Check if Sub --> Cast --> Div | COMMENT |
| LOW | …xruntime/python/tools/transformers/fusion_attention.py | 237 | # Check if concat node for (B,1,S,T) --> (B,N,S,T) already exists | COMMENT |
| LOW | …python/tools/transformers/fusion_qordered_attention.py | 45 | # Check if the second input to Reshape flows through a Constant node | COMMENT |
| LOW | …untime/python/tools/transformers/convert_generation.py | 1837 | # Check if root_input to Q/K/V paths is the same | COMMENT |
| LOW | …untime/python/tools/transformers/convert_generation.py | 1840 | # Check if Q/K/V paths all have bias or all don't have bias | COMMENT |
| LOW | onnxruntime/python/tools/transformers/run_benchmark.sh | 35 | # Set this to true to enable bfloat16 fastmath gemm kernels on aarch64 platforms with bfloat16 support | COMMENT |
| LOW | onnxruntime/python/tools/transformers/run_benchmark.sh | 68 | # Set it to false to skip testing. You can use it to dry run this script with the log file. | COMMENT |
| LOW | …time/python/tools/transformers/fusion_constant_fold.py | 39 | # Check if Transpose node only has one input and one output | COMMENT |
| LOW | …time/python/tools/transformers/fusion_constant_fold.py | 44 | # Check if input is initializer data | COMMENT |
| LOW | …time/python/tools/transformers/fusion_constant_fold.py | 69 | # Check if initializer data is 2D | COMMENT |
| LOW | …time/python/tools/transformers/fusion_constant_fold.py | 100 | # Add node to list of nodes to remove | COMMENT |
| LOW | …time/python/tools/transformers/fusion_constant_fold.py | 111 | # Check if Transpose node only has one input and one output | COMMENT |
| LOW | …time/python/tools/transformers/fusion_constant_fold.py | 116 | # Check if parent node is Transpose node with only one input and one output | COMMENT |
| LOW | …time/python/tools/transformers/fusion_constant_fold.py | 141 | # Add node to list of nodes to remove | COMMENT |
| LOW | …time/python/tools/transformers/fusion_skiplayernorm.py | 67 | # Check if b is a broadcastable skip for a | COMMENT |
| LOW | …time/python/tools/transformers/fusion_skiplayernorm.py | 70 | # Check if a is a broadcastable skip for b | COMMENT |
| LOW | onnxruntime/python/tools/transformers/onnx_model.py | 1004 | # Check if node output is an input of a subgraph node and not an input to a node in the main graph | COMMENT |
| LOW | onnxruntime/python/tools/transformers/onnx_model.py | 1397 | # Check if tensors are allclose | COMMENT |
| LOW | onnxruntime/python/tools/transformers/fusion_mha_dit.py | 398 | # Check if K^T comes from Transpose(perm=0,1,3,2) — if so, use K_BNSH directly | COMMENT |
| LOW | …on/tools/transformers/models/phi2/inference_example.py | 269 | # Check if we previously reached EOS token id or if generated token id is EOS token id | COMMENT |
| LOW | …on/tools/transformers/models/phi2/inference_example.py | 309 | # Set logits to zeros for next inference run and re-use memory buffer | COMMENT |
| LOW⚡ | …me/python/tools/transformers/models/llama/benchmark.py | 57 | # Set max_seq_len to 2048 for Microsoft LLaMA-2 model since that is the max value currently supported | COMMENT |
| LOW⚡ | …me/python/tools/transformers/models/llama/benchmark.py | 58 | # Set max_seq_len to config value for other models | COMMENT |
| LOW | …me/python/tools/transformers/models/llama/benchmark.py | 678 | # Check if past_present_share_buffer can be enabled (only for FP16 models with GQA) | COMMENT |
| 22 more matches not shown… | ||||
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| LOW | tools/python/sparsify_initializers.py | 18 | logger = logging.getLogger(__name__) | CODE |
| LOW | tools/python/trigger_and_wait_pipelines.py | 22 | logger = logging.getLogger(__name__) | CODE |
| LOW | tools/python/wgsl_template/__init__.py | 138 | __all__ = [ | CODE |
| LOW | tools/python/wgsl_template/code_generator/__init__.py | 36 | __all__ = [ | CODE |
| LOW | onnxruntime/core/flatbuffers/schema/compile_schema.py | 49 | __all__ = [splitext(basename(f))[0] for f in modules if isfile(f) and not f.endswith('__init__.py')] | STRING |
| LOW | …me/core/flatbuffers/ort_flatbuffers_py/fbs/__init__.py | 4 | __all__ = [splitext(basename(f))[0] for f in modules if isfile(f) and not f.endswith('__init__.py')] | CODE |
| LOW | …ation/lr_scheduler/lr_scheduler_test_data_generator.py | 13 | logger = logging.getLogger(__name__) | CODE |
| LOW | …time/test/python/transformers/cuda_plugin_ep_helper.py | 16 | logger = logging.getLogger(__name__) | CODE |
| LOW⚡ | onnxruntime/python/onnxruntime_inference_collection.py | 94 | def set_adapter_version(self, adapter_version: int) -> None: | CODE |
| LOW⚡ | onnxruntime/python/onnxruntime_inference_collection.py | 100 | def set_model_version(self, model_version: int) -> None: | CODE |
| LOW⚡ | onnxruntime/python/onnxruntime_inference_collection.py | 106 | def set_parameters(self, params: dict[str, OrtValue]) -> None: | CODE |
| LOW | onnxruntime/python/onnxruntime_inference_collection.py | 261 | def set_providers(self, providers=None, provider_options=None) -> None: | CODE |
| LOW | onnxruntime/python/onnxruntime_inference_collection.py | 1332 | def update_inplace(self, data) -> None: | CODE |
| LOW | onnxruntime/python/tools/symbolic_shape_infer.py | 21 | logger = logging.getLogger(__name__) | CODE |
| LOW | …ime/python/tools/quantization/matmul_bnb4_quantizer.py | 21 | logger = logging.getLogger(__name__) | CODE |
| LOW⚡ | onnxruntime/python/tools/quantization/preprocess.py | 13 | logger = logging.getLogger(__name__) | CODE |
| LOW | …me/python/tools/quantization/matmul_nbits_quantizer.py | 34 | logger = logging.getLogger(__name__) | CODE |
| LOW | …nxruntime/python/tools/quantization/shape_inference.py | 22 | logger = logging.getLogger(__name__) | CODE |
| LOW | onnxruntime/python/tools/microbench/benchmark.py | 17 | logger = logging.getLogger(__name__) | CODE |
| LOW⚡ | …time/python/tools/transformers/onnx_model_conformer.py | 12 | logger = logging.getLogger(__name__) | CODE |
| LOW⚡ | …e/python/tools/transformers/fusion_rotary_attention.py | 13 | logger = logging.getLogger(__name__) | CODE |
| LOW⚡ | …ime/python/tools/transformers/fusion_bart_attention.py | 12 | logger = logging.getLogger(__name__) | CODE |
| LOW⚡ | …untime/python/tools/transformers/onnx_model_bert_tf.py | 13 | logger = logging.getLogger(__name__) | CODE |
| LOW | …runtime/python/tools/transformers/io_binding_helper.py | 16 | logger = logging.getLogger(__name__) | CODE |
| LOW | …nxruntime/python/tools/transformers/onnx_model_unet.py | 21 | logger = logging.getLogger(__name__) | CODE |
| LOW | …nxruntime/python/tools/transformers/onnx_model_bart.py | 15 | logger = logging.getLogger(__name__) | CODE |
| LOW⚡ | …xruntime/python/tools/transformers/fusion_quickgelu.py | 12 | logger = logging.getLogger(__name__) | CODE |
| LOW | …nxruntime/python/tools/transformers/quantize_helper.py | 18 | logger = logging.getLogger(__name__) | CODE |
| LOW⚡ | …nxruntime/python/tools/transformers/onnx_model_gpt2.py | 14 | logger = logging.getLogger(__name__) | CODE |
| LOW | …untime/python/tools/transformers/shape_infer_helper.py | 29 | logger = logging.getLogger(__name__) | CODE |
| LOW⚡ | …ython/tools/transformers/fusion_conformer_attention.py | 10 | logger = logging.getLogger(__name__) | CODE |
| LOW⚡ | onnxruntime/python/tools/transformers/past_helper.py | 11 | logger = logging.getLogger(__name__) | CODE |
| LOW | …xruntime/python/tools/transformers/benchmark_helper.py | 28 | logger = logging.getLogger(__name__) | CODE |
| LOW⚡ | …nxruntime/python/tools/transformers/onnx_model_tnlr.py | 13 | logger = logging.getLogger(__name__) | CODE |
| LOW | …nxruntime/python/tools/transformers/onnx_model_sam2.py | 15 | logger = logging.getLogger(__name__) | CODE |
| LOW | …nxruntime/python/tools/transformers/shape_optimizer.py | 27 | logger = logging.getLogger(__name__) | CODE |
| LOW | onnxruntime/python/tools/transformers/float16.py | 26 | logger = logging.getLogger(__name__) | CODE |
| LOW⚡ | …ime/python/tools/transformers/onnx_model_bert_keras.py | 12 | logger = logging.getLogger(__name__) | CODE |
| LOW | onnxruntime/python/tools/transformers/onnx_exporter.py | 28 | logger = logging.getLogger(__name__) | CODE |
| LOW | onnxruntime/python/tools/transformers/optimizer.py | 47 | logger = logging.getLogger(__name__) | CODE |
| LOW⚡ | …nxruntime/python/tools/transformers/affinity_helper.py | 10 | logger = logging.getLogger(__name__) | CODE |
| LOW | onnxruntime/python/tools/transformers/onnx_model.py | 32 | logger = logging.getLogger(__name__) | CODE |
| LOW | …xruntime/python/tools/transformers/onnx_model_mmdit.py | 16 | logger = logging.getLogger(__name__) | CODE |
| LOW | …thon/tools/transformers/fusion_simplified_layernorm.py | 8 | logger = logging.getLogger(__name__) | CODE |
| LOW | …untime/python/tools/transformers/dynamo_onnx_helper.py | 25 | def update_edges(self, edge_mapping: dict) -> None: | CODE |
| LOW | …e/python/tools/transformers/convert_to_packing_mode.py | 21 | logger = logging.getLogger(__name__) | CODE |
| LOW | onnxruntime/python/tools/transformers/onnx_model_t5.py | 16 | logger = logging.getLogger(__name__) | CODE |
| LOW | …time/python/tools/transformers/models/t5/t5_decoder.py | 24 | logger = logging.getLogger(__name__) | CODE |
| LOW⚡ | …time/python/tools/transformers/models/t5/t5_encoder.py | 12 | logger = logging.getLogger(__name__) | CODE |
| LOW | …ools/transformers/models/t5/t5_encoder_decoder_init.py | 23 | logger = logging.getLogger(__name__) | CODE |
| LOW | …ntime/python/tools/transformers/models/t5/t5_helper.py | 20 | logger = logging.getLogger(__name__) | CODE |
| LOW | …ansformers/models/stable_diffusion/diffusion_models.py | 39 | logger = logging.getLogger(__name__) | CODE |
| LOW⚡ | …ormers/models/stable_diffusion/engine_builder_torch.py | 10 | logger = logging.getLogger(__name__) | CODE |
| LOW | …mers/models/stable_diffusion/engine_builder_ort_trt.py | 19 | logger = logging.getLogger(__name__) | CODE |
| LOW | …nsformers/models/stable_diffusion/optimize_pipeline.py | 38 | logger = logging.getLogger(__name__) | CODE |
| LOW | …ers/models/stable_diffusion/engine_builder_ort_cuda.py | 20 | logger = logging.getLogger(__name__) | CODE |
| LOW | …/transformers/models/stable_diffusion/ort_optimizer.py | 26 | logger = logging.getLogger(__name__) | CODE |
| LOW⚡ | …ls/transformers/models/longformer/longformer_helper.py | 13 | logger = logging.getLogger(__name__) | CODE |
| LOW | …e/python/tools/transformers/models/gpt2/gpt2_tester.py | 18 | logger = logging.getLogger(__name__) | CODE |
| LOW | …e/python/tools/transformers/models/gpt2/gpt2_helper.py | 28 | logger = logging.getLogger(__name__) | CODE |
| 33 more matches not shown… | ||||
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| CRITICAL | onnxruntime/test/testdata/capi_symbolic_dims.py | 7 | dim = output.type.tensor_type.shape.dim.add() | CODE |
| CRITICAL | onnxruntime/test/python/onnx_backend_test_series.py | 71 | super()._add_model_test(onnx.backend.test.case.test_case.TestCase(**attrs), kind) | CODE |
| CRITICAL | …e/python/tools/transformers/fusion_rotary_attention.py | 1402 | self.model.model.graph.value_info.remove(old_shape_infer[0]) | CODE |
| CRITICAL | …untime/python/tools/transformers/dynamo_onnx_helper.py | 68 | self.model.model.graph.node.remove(node) | CODE |
| CRITICAL | …untime/python/tools/transformers/dynamo_onnx_helper.py | 70 | self.model.model.graph.node.append(node) | CODE |
| CRITICAL | …untime/python/tools/transformers/dynamo_onnx_helper.py | 94 | self.model.model.graph.node.remove(node) | CODE |
| CRITICAL | …rttraining/python/training/ort_triton/_sorted_graph.py | 207 | node.type.tensor_type.shape.dim.add().dim_value = int(dim) | CODE |
| CRITICAL | …rttraining/python/training/ort_triton/_sorted_graph.py | 209 | node.type.tensor_type.shape.dim.add().dim_param = str(dim) | CODE |
| CRITICAL⚡ | …ocs/_exported_templates/default/styles/docfx.vendor.js | 1 | !function(e,t){"use strict";"object"==typeof module&&"object"==typeof module.exports?module.exports=e.document?t(e,!0):f | CODE |
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| HIGH | tools/python/resolve_absl_deps_dynamic.py | 87 | Parse CMakeLists.txt files to build a dependency graph. Parses CMakeLists.txt files in the extracted Abseil source | STRING |
| HIGH | tools/python/resolve_absl_deps_dynamic.py | 166 | Download and extract a specific version of Abseil, then generate the dependency graph. Args: version: The A | STRING |
| HIGH | onnxruntime/python/tools/transformers/bert_test_data.py | 311 | Find graph inputs for BERT model. First, we will deduce inputs from EmbedLayerNormalization node. If not found, | STRING |
| HIGH | …untime/python/tools/transformers/shape_infer_helper.py | 122 | Compare shape of two edges. Args: edge (str): name of edge edge_other (str): name of an | STRING |
| HIGH | …untime/python/tools/transformers/convert_generation.py | 675 | Create OnnxRuntime session. Args: model_path (str): onnx model path use_gpu (bool): use GPU or not | STRING |
| HIGH | …untime/python/tools/transformers/convert_generation.py | 3072 | Test PyTorch performance of text generation. Args: args (argparse.Namespace): arguments parsed from command | STRING |
| HIGH | …untime/python/tools/transformers/convert_generation.py | 3546 | Main entry function Args: argv (Optional[List[str]], optional): _description_. Defaults to None. se | STRING |
| HIGH | onnxruntime/python/tools/transformers/float16.py | 74 | Convert tensor float to float16. Args: tensor (TensorProto): the tensor to convert. min_positive_va | STRING |
| HIGH | onnxruntime/python/tools/transformers/float16.py | 179 | Convert tensor float type in the input ONNX model to tensor float16. Args: model (ModelProto or str): The O | STRING |
| HIGH | onnxruntime/python/tools/transformers/profiler.py | 268 | Create dummy inputs for GPT-2 model. Args: onnx_model (OnnxModel): ONNX model batch_size (int): bat | STRING |
| HIGH | onnxruntime/python/tools/transformers/profiler.py | 316 | Create dummy inputs for Longformer model. Args: onnx_model (OnnxModel): ONNX model batch_size (int) | STRING |
| HIGH | …ing/python/training/onnxblock/_training_graph_utils.py | 213 | Returns trainable and non trainable onnx model parameters. This function pulls out the model parameters from the in | STRING |
| HIGH | …aining/orttraining/python/training/ortmodule/_utils.py | 165 | Returns the first device found in the `module`'s parameters or None Args: module (torch.nn.Module): PyTorch | STRING |
| HIGH | …g/orttraining/python/training/utils/torch_io_helper.py | 127 | Extract the data schema by replacing every torch.Tensor value with _TensorStub, and return all tensors in a list. | STRING |
| HIGH | …g/orttraining/python/training/utils/torch_io_helper.py | 236 | Follows the schema to generate an output that is expected by the user. Depth first traversal to iterate over the sc | STRING |
| HIGH | …ng/orttraining/python/training/api/checkpoint_state.py | 76 | Gets the parameter associated with the given name Searches for the name in the parameters of the checkpoint sta | STRING |
| HIGH | …ng/orttraining/python/training/api/checkpoint_state.py | 144 | Gets the property associated with the given name Searches for the name in the properties of the checkpoint stat | STRING |
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| HIGH | tools/ci_build/build.py | 1261 | ["cmd", "/s", "/c", "call .\\emsdk_env && set"], | CODE |
| HIGH | tools/ci_build/build.py | 1268 | ["sh", "-c", ". ./emsdk_env.sh && printenv"], | CODE |
| HIGH | tools/ci_build/coverage.py | 52 | adb_shell("cd /data/local/tmp && tar -zcf gcda_files.tar.gz *.dir") | CODE |
| HIGH | onnxruntime/test/python/onnxruntime_test_python.py | 670 | # The entry my be None (null) but it should be present | COMMENT |
| HIGH | …st/python/transformers/test_onnx_attention/test_gqa.py | 2529 | (!is_gqa || head_size == v_head_size) clause of the MEA eligibility | STRING |
| HIGH | …st/python/transformers/test_onnx_attention/test_gqa.py | 2884 | predicate at attention.cc explicitly excludes is_gqa && std::is_same<T, | STRING |
| HIGH | onnxruntime/test/common/test_cpuinfo_sysfs_fallback.py | 178 | if (arm_linux_processors_count == (unsigned int)nproc && valid_processors == processors_count) { | CODE |
| HIGH | onnxruntime/test/common/test_cpuinfo_sysfs_fallback.py | 232 | return (strcmp(path, CPU_POSSIBLE) == 0 || strcmp(path, CPU_PRESENT) == 0); | CODE |
| HIGH | onnxruntime/test/common/test_cpuinfo_sysfs_fallback.py | 283 | if (path && is_blocked(path)) { | CODE |
| HIGH | onnxruntime/test/common/test_cpuinfo_sysfs_fallback.py | 302 | if (path && is_blocked(path)) { | CODE |
| HIGH | onnxruntime/test/common/test_cpuinfo_sysfs_fallback.py | 447 | return (strcmp(path, CPU_POSSIBLE) == 0 || strcmp(path, CPU_PRESENT) == 0); | CODE |
| HIGH | onnxruntime/test/common/test_cpuinfo_sysfs_fallback.py | 492 | if (path && is_blocked(path)) { errno = ENOENT; return -1; } | CODE |
| HIGH | onnxruntime/test/common/test_cpuinfo_sysfs_fallback.py | 508 | if (path && is_blocked(path)) { errno = ENOENT; return -1; } | CODE |
| HIGH | …ools/transformers/models/whisper/whisper_jump_times.py | 244 | while (i > 0 || j > 0) { | CODE |
| HIGH | …ools/transformers/models/whisper/whisper_jump_times.py | 284 | if (c0 < c1 && c0 < c2) { | CODE |
| HIGH | …ools/transformers/models/whisper/whisper_jump_times.py | 287 | } else if (c1 < c0 && c1 < c2) { | CODE |
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| LOW⚡ | tools/python/util/android/android.py | 249 | # Step 1: List running devices | COMMENT |
| LOW⚡ | tools/python/util/android/android.py | 258 | # Step 2: Check each running emulator's AVD name | COMMENT |
| LOW | onnxruntime/core/framework/copy.h | 168 | // Step 1: if there is anything left in the contiguous span that we are starting in, finish copying it | COMMENT |
| LOW⚡ | onnxruntime/core/framework/copy.h | 183 | // Step 2: copy contiguous span by contiguous span until we reach the penultimate span | COMMENT |
| LOW⚡ | onnxruntime/core/framework/copy.h | 190 | // Step 3: finish off the last (possibly partial) span manually, making sure that we don't go past the last | COMMENT |
| LOW | …ntime/core/providers/qnn/builder/qnn_backend_manager.h | 169 | // NOTE: This function locks the internal `logger_recursive_mutex_`. | COMMENT |
| LOW | …ntime/core/providers/qnn/builder/qnn_backend_manager.h | 209 | // NOTE: This function locks the internal `logger_recursive_mutex_`. | COMMENT |
| LOW | …ntime/core/providers/qnn/builder/qnn_backend_manager.h | 328 | // NOTE: This function locks the internal `logger_recursive_mutex_`. | COMMENT |
| LOW | …ntime/core/providers/qnn/builder/qnn_backend_manager.h | 332 | // NOTE: This function indirectly locks the internal `logger_recursive_mutex_` via nested function calls. | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_qkv.cpp | 142 | // Step 1: QK^T GEMM with quantized K block | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_qkv.cpp | 190 | // Step 2: Apply causal mask and Step 3: Online softmax update | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_qkv.cpp | 257 | // Step 4: Accumulate O += S_exp * V_block using fused dequant+GEMM | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_qkv.cpp | 393 | // Step 1: QK^T GEMM for this KV chunk | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_qkv.cpp | 433 | // Step 2: Apply causal mask | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_qkv.cpp | 455 | // Step 3: Compute local softmax statistics (m, l) and exp scores | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_qkv.cpp | 487 | // Step 4: S_exp * V_block -> partial_output | COMMENT |
| LOW⚡ | onnxruntime/core/mlas/lib/flashattn_gqa.cpp | 733 | // Step 2: local-window masking (no causal mask needed for decode). | COMMENT |
| LOW⚡ | onnxruntime/core/mlas/lib/flashattn_gqa.cpp | 740 | // Step 3: softmax over scores[0..T). | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_gqa.cpp | 213 | // Step 1: QK^T GEMM with FP32 K block | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_gqa.cpp | 260 | // Step 2: Apply causal mask and Step 3: Online softmax update | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_gqa.cpp | 327 | // Step 4: Accumulate O += S_exp * V_block | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_gqa.cpp | 452 | // Step 1: QK^T GEMV for this KV chunk (M = 1) | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_gqa.cpp | 479 | // Step 2: Apply causal mask | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_gqa.cpp | 501 | // Step 3: Compute local softmax statistics (m, l) and exp scores | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_gqa.cpp | 533 | // Step 4: S_exp * V_block -> partial_output (M = 1) | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_gqa.cpp | 711 | // Step 1: QK^T GEMV -> scores[0..T) | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_gqa.cpp | 764 | // Step 4: S_exp * V GEMV -> temp_output, then normalize by 1/l. | COMMENT |
| LOW⚡ | …ython/quantization/test_qoperator_adjust_int32_bias.py | 29 | # Step 1: reshape to (C_out, -1) to ensure per-channel broadcasting | COMMENT |
| LOW⚡ | …ython/quantization/test_qoperator_adjust_int32_bias.py | 36 | # Step 2: reshape back to original shape | COMMENT |
| LOW⚡ | …est/python/orttraining_test_fused_adam_cpu_fallback.py | 46 | # Step 1: load _multi_tensor_apply as a top-level module (no package needed, | COMMENT |
| LOW | …est/python/orttraining_test_fused_adam_cpu_fallback.py | 58 | # Step 2: load fused_adam.py with __package__ = _PKG so its relative import | COMMENT |
| LOW⚡ | …ining/orttraining/python/training/ortmodule/options.py | 143 | # WARNING: The shape inference of com.microsoft::SoftmaxCrossEntropyLossInternal type is missing, so | COMMENT |
| LOW⚡ | …ining/orttraining/python/training/ortmodule/options.py | 144 | # WARNING: The shape inference of com.microsoft::PythonOp type is missing, so it may result in wrong | COMMENT |
| LOW⚡ | …ining/orttraining/python/training/ortmodule/options.py | 145 | # WARNING: The shape inference of org.pytorch.aten::ATen type is missing, so it may result in wrong | COMMENT |
| LOW⚡ | …ining/orttraining/python/training/ortmodule/options.py | 146 | # WARNING: The shape inference of prim::Constant type is missing, so it may result in wrong shape in | COMMENT |
| LOW | docs/ORTModule_ModuleWithLoss_Wrapper.md | 20 | ### Step 1: Define `ModuleWithLoss` Class | COMMENT |
| LOW | docs/ORTModule_ModuleWithLoss_Wrapper.md | 43 | ### Step 2: Define a sample training script | COMMENT |
| LOW | …ing/PartitioningWithAnnotationsAndMemoryConstraints.md | 223 | ### Step 1: Collect Memory Statistics (Profiling Run) | COMMENT |
| LOW | …ing/PartitioningWithAnnotationsAndMemoryConstraints.md | 274 | ### Step 2: Partition with a Memory Budget | COMMENT |
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| LOW⚡ | tools/python/util/android/android.py | 249 | # Step 1: List running devices | COMMENT |
| LOW⚡ | tools/python/util/android/android.py | 258 | # Step 2: Check each running emulator's AVD name | COMMENT |
| LOW | onnxruntime/core/framework/copy.h | 168 | // Step 1: if there is anything left in the contiguous span that we are starting in, finish copying it | COMMENT |
| LOW⚡ | onnxruntime/core/framework/copy.h | 183 | // Step 2: copy contiguous span by contiguous span until we reach the penultimate span | COMMENT |
| LOW⚡ | onnxruntime/core/framework/copy.h | 190 | // Step 3: finish off the last (possibly partial) span manually, making sure that we don't go past the last | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_qkv.cpp | 142 | // Step 1: QK^T GEMM with quantized K block | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_qkv.cpp | 190 | // Step 2: Apply causal mask and Step 3: Online softmax update | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_qkv.cpp | 257 | // Step 4: Accumulate O += S_exp * V_block using fused dequant+GEMM | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_qkv.cpp | 393 | // Step 1: QK^T GEMM for this KV chunk | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_qkv.cpp | 433 | // Step 2: Apply causal mask | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_qkv.cpp | 455 | // Step 3: Compute local softmax statistics (m, l) and exp scores | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_qkv.cpp | 487 | // Step 4: S_exp * V_block -> partial_output | COMMENT |
| LOW⚡ | onnxruntime/core/mlas/lib/flashattn_gqa.cpp | 733 | // Step 2: local-window masking (no causal mask needed for decode). | COMMENT |
| LOW⚡ | onnxruntime/core/mlas/lib/flashattn_gqa.cpp | 740 | // Step 3: softmax over scores[0..T). | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_gqa.cpp | 213 | // Step 1: QK^T GEMM with FP32 K block | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_gqa.cpp | 260 | // Step 2: Apply causal mask and Step 3: Online softmax update | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_gqa.cpp | 327 | // Step 4: Accumulate O += S_exp * V_block | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_gqa.cpp | 452 | // Step 1: QK^T GEMV for this KV chunk (M = 1) | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_gqa.cpp | 479 | // Step 2: Apply causal mask | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_gqa.cpp | 501 | // Step 3: Compute local softmax statistics (m, l) and exp scores | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_gqa.cpp | 533 | // Step 4: S_exp * V_block -> partial_output (M = 1) | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_gqa.cpp | 711 | // Step 1: QK^T GEMV -> scores[0..T) | COMMENT |
| LOW | onnxruntime/core/mlas/lib/flashattn_gqa.cpp | 764 | // Step 4: S_exp * V GEMV -> temp_output, then normalize by 1/l. | COMMENT |
| LOW⚡ | …ython/quantization/test_qoperator_adjust_int32_bias.py | 29 | # Step 1: reshape to (C_out, -1) to ensure per-channel broadcasting | COMMENT |
| LOW⚡ | …ython/quantization/test_qoperator_adjust_int32_bias.py | 36 | # Step 2: reshape back to original shape | COMMENT |
| LOW⚡ | …est/python/orttraining_test_fused_adam_cpu_fallback.py | 46 | # Step 1: load _multi_tensor_apply as a top-level module (no package needed, | COMMENT |
| LOW | …est/python/orttraining_test_fused_adam_cpu_fallback.py | 58 | # Step 2: load fused_adam.py with __package__ = _PKG so its relative import | COMMENT |
| LOW | include/onnxruntime/core/framework/kernel_def_builder.h | 134 | // This variable stores <input_offset, output_offset> for the variadic alias mapping | COMMENT |
| LOW | include/onnxruntime/core/graph/node_arg.h | 148 | // This variable stores the actual tensor data of the shape as a TensorShapeProto after executing | COMMENT |
| LOW | include/onnxruntime/core/graph/node_arg.h | 161 | // This variable stores the actual scalar value. | COMMENT |
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| MEDIUM | …ing/test/python/orttraining_test_ortmodule_onnx_ops.py | 153 | CODE | |
| MEDIUM | …ing/test/python/orttraining_test_ortmodule_onnx_ops.py | 157 | CODE | |
| MEDIUM | …ing/test/python/orttraining_test_ortmodule_onnx_ops.py | 165 | CODE | |
| MEDIUM | …ing/test/python/orttraining_test_ortmodule_onnx_ops.py | 166 | CODE | |
| MEDIUM | …ing/test/python/orttraining_test_ortmodule_onnx_ops.py | 168 | CODE | |
| MEDIUM | …ing/test/python/orttraining_test_ortmodule_onnx_ops.py | 169 | CODE | |
| MEDIUM | …ing/test/python/orttraining_test_ortmodule_onnx_ops.py | 170 | CODE | |
| MEDIUM | …ing/test/python/orttraining_test_ortmodule_onnx_ops.py | 171 | CODE | |
| MEDIUM | …ing/test/python/orttraining_test_ortmodule_onnx_ops.py | 172 | CODE | |
| MEDIUM | …ing/test/python/orttraining_test_ortmodule_onnx_ops.py | 173 | CODE | |
| MEDIUM | …ing/test/python/orttraining_test_ortmodule_onnx_ops.py | 175 | CODE | |
| MEDIUM | …ing/test/python/orttraining_test_ortmodule_onnx_ops.py | 176 | CODE | |
| MEDIUM | …ing/test/python/orttraining_test_ortmodule_onnx_ops.py | 177 | CODE | |
| MEDIUM | …ing/test/python/orttraining_test_ortmodule_onnx_ops.py | 178 | CODE | |
| MEDIUM | …ing/test/python/orttraining_test_ortmodule_onnx_ops.py | 179 | CODE | |
| MEDIUM | …ing/test/python/orttraining_test_ortmodule_onnx_ops.py | 181 | CODE |
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 338 | # Note: For files without extension you can use no_extension as a placeholder. | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 923 | # If the value of the INPUT tag contains directories, you can use the | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 965 | # If the value of the INPUT tag contains directories, you can use the | COMMENT |
| MEDIUM | tools/ci_build/github/Doxyfile_csharp.cfg | 991 | # If the value of the EXAMPLE_PATH tag contains directories, you can use the | COMMENT |
| LOW | onnxruntime/test/python/transformers/test_moe_cuda.py | 945 | # the current expert. We need to make sure to multiply the output hidden | COMMENT |
| LOW | onnxruntime/test/python/transformers/test_moe_cuda.py | 1132 | # the current expert. We need to make sure to multiply the output hidden | COMMENT |
| MEDIUM | onnxruntime/python/tools/transformers/optimizer.py | 18 | # (3) Some model cannot be handled by OnnxRuntime, and you can modify this script to get optimized model. | COMMENT |
| MEDIUM | …ools/transformers/models/t5/t5_encoder_decoder_init.py | 218 | # Workaround as mentioned earlier: change numeric dim_param to dim_value | COMMENT |
| MEDIUM | …ools/transformers/models/longformer/convert_to_onnx.py | 30 | # GPU is not needed for this script. You can run it in CPU. For --optimize_onnx, you can use either onnxruntime or onnxr | COMMENT |
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| LOW | …utionProvider/src/External/DirectMLHelpers/DirectMLX.h | 2000 | // TODO: implement me | COMMENT |
| LOW | onnxruntime/test/perftest/test_session.h | 21 | // TODO: implement it | COMMENT |
| LOW | onnxruntime/test/perftest/ort_test_session.h | 66 | // TODO: implement a customized allocator, then we can remove output_names_ to simplify this code | COMMENT |
| LOW | js/web/lib/wasm/session-handler-inference.ts | 148 | // TODO: implement profiling | COMMENT |
| LOW | js/web/lib/wasm/jsep/webgpu/ops/conv.ts | 315 | // TODO: implement conv2dWithIm2Col() | COMMENT |
| LOW | js/web/lib/wasm/jsep/webgpu/ops/binary-op.ts | 288 | // TODO: implement vectorized pow | COMMENT |
| LOW | …ning/training_ops/cuda/loss/softmaxcrossentropy_impl.h | 71 | // TODO: implement reduction type of NONE | COMMENT |
| LOW | …ning/training_ops/cuda/loss/softmaxcrossentropy_impl.h | 82 | // TODO: implement reduction type of NONE | COMMENT |
| LOW | …ning/training_ops/cuda/loss/softmaxcrossentropy_impl.h | 93 | // TODO: implement reduction type of NONE | COMMENT |
| LOW | …ning/training_ops/cuda/loss/softmaxcrossentropy_impl.h | 104 | // TODO: implement reduction type of NONE | COMMENT |
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| LOW | …ime/test/python/transformers/run_disable_sync_check.sh | 22 | # Usage: | COMMENT |
| LOW⚡ | …xruntime/test/python/transformers/profile_qmoe_gemv.sh | 9 | # Usage: | COMMENT |
| LOW⚡ | onnxruntime/test/python/transformers/profile_gqa.sh | 9 | # Usage: | COMMENT |
| LOW⚡ | …me/test/python/transformers/profile_skip_layer_norm.sh | 9 | # Usage: | COMMENT |
| LOW | js/build_webgpu.sh | 7 | # Usage: | COMMENT |
| LOW | orttraining/tools/scripts/opset12_model_transform.py | 10 | # Example usage: | COMMENT |
| LOW | …soft.ML.OnnxRuntime/Training/TrainingSession.shared.cs | 294 | /// Example usage: | COMMENT |
| LOW | …soft.ML.OnnxRuntime/Training/TrainingSession.shared.cs | 419 | /// Example usage: | COMMENT |
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| HIGH | onnxruntime/test/ep_weight_sharing_ctx_gen/README.md | 75 | # In this example, we pick the first one. | COMMENT |
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| LOW | …e/test/autoep/library/example_plugin_ep/ep_custom_op.h | 18 | // 2. A "placeholder" OrtCustomOp with an empty kernel implementation | COMMENT |
| LOW | include/onnxruntime/core/session/onnxruntime_ep_c_api.h | 2972 | * 2. A "placeholder" OrtCustomOp with an empty kernel implementation | COMMENT |
| LOW | java/src/test/java/ai/onnxruntime/InferenceTest.java | 1595 | Assertions.assertEquals("dummy_value", modelMetadata.getCustomMetadata().get("dummy_key")); | CODE |
| LOW | …Microsoft.ML.OnnxRuntime.Tests.Common/InferenceTest.cs | 1662 | Assert.Equal("dummy_value", modelMetadata.CustomMetadataMap["dummy_key"]); | CODE |